@@ -30,6 +30,7 @@
 #	include <config.h>
 #endif
 
+#include <glibmm.h>
 #include "layeractionmanager.h"
 #include "trees/layertree.h"
 #include <synfig/context.h>
@@ -289,7 +290,7 @@ LayerActionManager::refresh()
 				}
 			}
 
-			if(!multiple_selected && layer->get_name()=="PasteCanvas")
+			if(!multiple_selected && etl::handle<Layer_PasteCanvas>::cast_dynamic(layer))
 			{
 				if (select_all_child_layers_connection)
 					select_all_child_layers_connection.disconnect();
@@ -311,7 +312,9 @@ LayerActionManager::refresh()
 		}
 	}
 
-	ui_info=("<ui>"
+	String full_ui_info;
+	full_ui_info=
+			 "<ui>"
 			   "<popup action='menu-main'>"
 			     "<menu action='menu-layer'>" +
 			 	   ui_info +
@@ -322,8 +325,22 @@ LayerActionManager::refresh()
 			 	   "<separator/>"
 			     "</menu>"
 			   "</popup>" +
-			 "</ui>");
-	popup_id_=get_ui_manager()->add_ui_from_string(ui_info);
+			 "</ui>";
+	popup_id_=get_ui_manager()->add_ui_from_string(full_ui_info);
+	full_ui_info=
+			 "<ui>"
+			   "<menubar action='menubar-main'>"
+			     "<menu action='menu-layer'>" +
+			 	   ui_info +
+				   "<separator/>"
+			       "<menuitem action='cut' />"
+			 	   "<menuitem action='copy' />"
+			 	   "<menuitem action='paste' />"
+			 	   "<separator/>"
+			     "</menu>"
+			   "</menubar>" +
+			 "</ui>";
+	popup_id_=get_ui_manager()->add_ui_from_string(full_ui_info);
 #ifdef ONE_ACTION_GROUP
 #else
 	get_ui_manager()->insert_action_group(action_group_);
@@ -468,7 +485,7 @@ LayerActionManager::export_dup_nodes(synfig::Layer::Handle layer, Canvas::Handle
 		for (Layer::ParamList::const_iterator iter(param_list.begin())
 				 ; iter != param_list.end()
 				 ; iter++)
-			if (layer->dynamic_param_list().count(iter->first)==0 && iter->second.get_type()==ValueBase::TYPE_CANVAS)
+			if (layer->dynamic_param_list().count(iter->first)==0 && iter->second.get_type()==type_canvas)
 			{
 				Canvas::Handle subcanvas(iter->second.get(Canvas::Handle()));
 				if (subcanvas && subcanvas->is_inline())
@@ -479,7 +496,7 @@ LayerActionManager::export_dup_nodes(synfig::Layer::Handle layer, Canvas::Handle
 		for (Layer::DynamicParamList::const_iterator iter(layer->dynamic_param_list().begin())
 				 ; iter != layer->dynamic_param_list().end()
 				 ; iter++)
-			if (iter->second->get_type()==ValueBase::TYPE_CANVAS)
+			if (iter->second->get_type()==type_canvas)
 			{
 				Canvas::Handle canvas((*iter->second)(0).get(Canvas::Handle()));
 				if (canvas->is_inline())
