@@ -41,6 +41,8 @@
 #include <synfigapp/action.h>
 #include <synfig/interpolation.h>
 
+#include <gdkmm.h>
+
 #include "general.h"
 
 #endif
@@ -72,7 +74,7 @@ using namespace synfig;
 
 /* === M E T H O D S ======================================================= */
 
-static Glib::RefPtr<Gdk::Pixbuf> _tree_pixbuf_table_value_type[(int)synfig::ValueBase::TYPE_END];
+static std::map< int, Glib::RefPtr<Gdk::Pixbuf> > _tree_pixbuf_table_value_type;
 static Glib::RefPtr<Gdk::Pixbuf> _tree_pixbuf_table_interpolation[(int)INTERPOLATION_CLAMPED+1];
 
 #ifdef WIN32
@@ -81,31 +83,28 @@ IconController::IconController(const synfig::String& basepath)
 IconController::IconController(const synfig::String& /*basepath*/)
 #endif
 {
+	
+	icon_factory=Gtk::IconFactory::create();
+}
+
+IconController::~IconController()
+{
+	_tree_pixbuf_table_value_type.clear();
+	for(int i(0);i<((int)INTERPOLATION_CLAMPED+1);i++)
+		_tree_pixbuf_table_interpolation[i]=Glib::RefPtr<Gdk::Pixbuf>();
+
+	icon_factory->remove_default();
+}
+
+void
+IconController::init_icons(const synfig::String& path_to_icons)
+{
+	
 	Gtk::IconSource icon_source;
 	icon_source.set_direction_wildcarded();
 	icon_source.set_state_wildcarded();
 	icon_source.set_size_wildcarded();
-	icon_factory=Gtk::IconFactory::create();
-
-	std::string path_to_icons;
-#ifdef WIN32
-	path_to_icons=basepath+ETL_DIRECTORY_SEPARATOR+".."+ETL_DIRECTORY_SEPARATOR+IMAGE_DIR;
-#else
-	path_to_icons=IMAGE_DIR;
-#endif
-
-	char* synfig_root=getenv("SYNFIG_ROOT");
-	if(synfig_root) {
-		path_to_icons=synfig_root;
-		path_to_icons+=ETL_DIRECTORY_SEPARATOR;
-		path_to_icons+="share";
-		path_to_icons+=ETL_DIRECTORY_SEPARATOR;
-		path_to_icons+="pixmaps";
-		path_to_icons+=ETL_DIRECTORY_SEPARATOR;
-		path_to_icons+="synfigstudio";
-	}
-	path_to_icons+=ETL_DIRECTORY_SEPARATOR;
-
+	
 	try{
 	Gtk::Window::set_default_icon_from_file(path_to_icons+"synfig_icon."+IMAGE_EXT);
 	} catch(...)
@@ -116,16 +115,16 @@ IconController::IconController(const synfig::String& /*basepath*/)
 #define INIT_STOCK_ICON(name,iconfile,desc){							\
 	Gtk::StockItem stockitem(Gtk::StockID("synfig-" #name),desc); \
 	Gtk::Stock::add(stockitem);								\
-	Gtk::IconSet icon_set;									\
+	Glib::RefPtr<Gtk::IconSet> icon_set = Gtk::IconSet::create(); \
 	icon_source.set_filename(path_to_icons+iconfile);							\
-	icon_set.add_source(icon_source);						\
+	icon_set->add_source(icon_source);						\
 	icon_factory->add(stockitem.get_stock_id(),icon_set); \
 	}
 
 #define INIT_STOCK_ICON_CLONE(name,stockid,desc){							\
 	Gtk::StockItem stockitem(Gtk::StockID("synfig-" #name),desc); \
 	Gtk::Stock::add(stockitem);								\
-	Gtk::IconSet icon_set;									\
+	Glib::RefPtr<Gtk::IconSet> icon_set = Gtk::IconSet::create(); \
 	if(Gtk::Stock::lookup(stockitem.get_stock_id(),icon_set))	\
 	icon_factory->add(stockitem.get_stock_id(),icon_set); \
 	}
@@ -151,23 +150,25 @@ IconController::IconController(const synfig::String& /*basepath*/)
 
 	// ToolBox Tools
 	INIT_STOCK_ICON(normal,"tool_normal_icon."IMAGE_EXT,_("Transform Tool"));
-        INIT_STOCK_ICON(polygon,"tool_polyline_icon."IMAGE_EXT,_("Polygon Tool"));
-        INIT_STOCK_ICON(bline,"tool_spline_icon."IMAGE_EXT,_("Spline Tool"));
-        INIT_STOCK_ICON(eyedrop,"tool_eyedrop_icon."IMAGE_EXT,_("Eyedrop Tool"));
-        INIT_STOCK_ICON(fill,"tool_fill_icon."IMAGE_EXT,_("Fill Tool"));
-        INIT_STOCK_ICON(draw,"tool_draw_icon."IMAGE_EXT,_("Draw Tool"));
-        INIT_STOCK_ICON(sketch,"tool_sketch_icon."IMAGE_EXT,_("Sketch Tool"));
-        INIT_STOCK_ICON(circle,"tool_circle_icon."IMAGE_EXT,_("Circle Tool"));
-        INIT_STOCK_ICON(rectangle,"tool_rectangle_icon."IMAGE_EXT,_("Rectangle Tool"));
-        INIT_STOCK_ICON(smooth_move,"tool_smooth_move_icon."IMAGE_EXT,_("SmoothMove Tool"));
-        INIT_STOCK_ICON(rotate,"tool_rotate_icon."IMAGE_EXT,"Rotate Tool");
-        INIT_STOCK_ICON(width,"tool_width_icon."IMAGE_EXT,_("Width Tool"));
-        INIT_STOCK_ICON(scale,"tool_scale_icon."IMAGE_EXT,"Scale Tool");
-        INIT_STOCK_ICON(zoom,"tool_zoom_icon."IMAGE_EXT,_("Zoom Tool"));
-        INIT_STOCK_ICON(mirror,"tool_mirror_icon."IMAGE_EXT,_("Mirror Tool"));
-        INIT_STOCK_ICON(text,"tool_text_icon."IMAGE_EXT,"Text Tool");
-        INIT_STOCK_ICON(gradient,"tool_gradient_icon."IMAGE_EXT,_("Gradient Tool"));
-        INIT_STOCK_ICON(star,"tool_star_icon."IMAGE_EXT,_("Star Tool"));
+	INIT_STOCK_ICON(polygon,"tool_polyline_icon."IMAGE_EXT,_("Polygon Tool"));
+	INIT_STOCK_ICON(bline,"tool_spline_icon."IMAGE_EXT,_("Spline Tool"));
+	INIT_STOCK_ICON(eyedrop,"tool_eyedrop_icon."IMAGE_EXT,_("Eyedrop Tool"));
+	INIT_STOCK_ICON(fill,"tool_fill_icon."IMAGE_EXT,_("Fill Tool"));
+	INIT_STOCK_ICON(draw,"tool_draw_icon."IMAGE_EXT,_("Draw Tool"));
+	INIT_STOCK_ICON(lasso,"tool_cutout_icon."IMAGE_EXT,_("Cutout Tool"));
+	INIT_STOCK_ICON(brush,"tool_brush_icon."IMAGE_EXT,_("Brush Tool"));
+	INIT_STOCK_ICON(sketch,"tool_sketch_icon."IMAGE_EXT,_("Sketch Tool"));
+	INIT_STOCK_ICON(circle,"tool_circle_icon."IMAGE_EXT,_("Circle Tool"));
+	INIT_STOCK_ICON(rectangle,"tool_rectangle_icon."IMAGE_EXT,_("Rectangle Tool"));
+	INIT_STOCK_ICON(smooth_move,"tool_smooth_move_icon."IMAGE_EXT,_("SmoothMove Tool"));
+	INIT_STOCK_ICON(rotate,"tool_rotate_icon."IMAGE_EXT,"Rotate Tool");
+	INIT_STOCK_ICON(width,"tool_width_icon."IMAGE_EXT,_("Width Tool"));
+	INIT_STOCK_ICON(scale,"tool_scale_icon."IMAGE_EXT,"Scale Tool");
+	INIT_STOCK_ICON(zoom,"tool_zoom_icon."IMAGE_EXT,_("Zoom Tool"));
+	INIT_STOCK_ICON(mirror,"tool_mirror_icon."IMAGE_EXT,_("Mirror Tool"));
+	INIT_STOCK_ICON(text,"tool_text_icon."IMAGE_EXT,"Text Tool");
+	INIT_STOCK_ICON(gradient,"tool_gradient_icon."IMAGE_EXT,_("Gradient Tool"));
+	INIT_STOCK_ICON(star,"tool_star_icon."IMAGE_EXT,_("Star Tool"));
 	//ToolBox Others
 	INIT_STOCK_ICON(reset_colors,"reset_colors_icon."IMAGE_EXT,_("Reset Colors"));
 	INIT_STOCK_ICON(swap_colors,"swap_colors_icon."IMAGE_EXT,_("Swap Colors"));
@@ -202,7 +203,7 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(layer_filter_colorcorrect,"layer_filter_colorcorrect_icon."IMAGE_EXT,_("Color Correct Layer"));
 	INIT_STOCK_ICON(layer_filter_halftone2,"layer_filter_halftone2_icon."IMAGE_EXT,_("Halftone 2 Layer"));
 	INIT_STOCK_ICON(layer_filter_halftone3,"layer_filter_halftone3_icon."IMAGE_EXT,_("Halftone 3 Layer"));
-	INIT_STOCK_ICON(layer_filter_lumakey,"layer_filter_lumakey_icon."IMAGE_EXT,_("Luna Key Layer"));
+	INIT_STOCK_ICON(layer_filter_lumakey,"layer_filter_lumakey_icon."IMAGE_EXT,_("Luma Key Layer"));
 	// Fractal Layers
 	INIT_STOCK_ICON(layer_fractal_julia,"layer_fractal_julia_icon."IMAGE_EXT,_("Julia Set Layer"));
 	INIT_STOCK_ICON(layer_fractal_mandelbrot,"layer_fractal_mandelbrot_icon."IMAGE_EXT,_("Mandelbrot Set Layer"));
@@ -220,7 +221,7 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(layer_gradient_conical,"layer_gradient_conical_icon."IMAGE_EXT,_("Conical Gradient Layer"));
 	INIT_STOCK_ICON(layer_gradient_curve,"layer_gradient_curve_icon."IMAGE_EXT,_("Curve Gradient Layer"));
 	INIT_STOCK_ICON(layer_gradient_noise,"layer_gradient_noise_icon."IMAGE_EXT,_("Noise Gradient Layer"));
-	INIT_STOCK_ICON(layer_gradient_lineal,"layer_gradient_lineal_icon."IMAGE_EXT,_("Linear Gradient Layer"));
+	INIT_STOCK_ICON(layer_gradient_linear,"layer_gradient_linear_icon."IMAGE_EXT,_("Linear Gradient Layer"));
 	INIT_STOCK_ICON(layer_gradient_radial,"layer_gradient_radial_icon."IMAGE_EXT,_("Radial Gradient Layer"));
 	INIT_STOCK_ICON(layer_gradient_spiral,"layer_gradient_spiral_icon."IMAGE_EXT,_("Spiral Gradient Layer"));
 	// Other Layers
@@ -230,6 +231,8 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(layer_other_plant,"layer_other_plant_icon."IMAGE_EXT,_("Plant Layer"));
 	INIT_STOCK_ICON(layer_other_stroboscope,"layer_other_stroboscope_icon."IMAGE_EXT,_("Stroboscope Layer"));
 	INIT_STOCK_ICON(layer_other_supersample,"layer_other_supersample_icon."IMAGE_EXT,_("Super Sample Layer"));
+	INIT_STOCK_ICON(layer_other_sound,"layer_other_sound_icon."IMAGE_EXT,_("Sound Layer"));
+	INIT_STOCK_ICON(layer_other_switch,"layer_other_switch_icon."IMAGE_EXT,_("Switch Layer"));
 	INIT_STOCK_ICON(layer_other_skeleton,"layer_other_skeleton_icon."IMAGE_EXT,_("Skeleton Layer"));
 	INIT_STOCK_ICON(layer_other_text,"layer_other_text_icon."IMAGE_EXT,_("Text Layer"));
 	INIT_STOCK_ICON(layer_other_timeloop,"layer_other_timeloop_icon."IMAGE_EXT,_("Time Loop Layer"));
@@ -273,19 +276,21 @@ IconController::IconController(const synfig::String& /*basepath*/)
 
 	INIT_STOCK_ICON(animate_mode_off,"animate_mode_off_icon."IMAGE_EXT,_("Animate Mode Off"));
 	INIT_STOCK_ICON(animate_mode_on,"animate_mode_on_icon."IMAGE_EXT,_("Animate Mode On"));
+	
+	INIT_STOCK_ICON(jack, "jack_icon."IMAGE_EXT, _("JACK"));
 
 	INIT_STOCK_ICON(set_outline_color,"set_outline_color."IMAGE_EXT,_("Set as Outline"));
 	INIT_STOCK_ICON(set_fill_color,"set_fill_color."IMAGE_EXT,_("Set as Fill"));
 
-	INIT_STOCK_ICON(animate_seek_begin,"animate_seek_begin_icon."IMAGE_EXT,_("Seek to begin"));
-	INIT_STOCK_ICON(animate_seek_prev_keyframe,"animate_seek_prev_keyframe_icon."IMAGE_EXT,_("Previous keyframe"));
-	INIT_STOCK_ICON(animate_seek_prev_frame,"animate_seek_prev_frame_icon."IMAGE_EXT,_("Previous frame"));
+	INIT_STOCK_ICON(animate_seek_begin,"animate_seek_begin_icon."IMAGE_EXT,_("Seek to Begin"));
+	INIT_STOCK_ICON(animate_seek_prev_keyframe,"animate_seek_prev_keyframe_icon."IMAGE_EXT,_("Seek to Previous Keyframe"));
+	INIT_STOCK_ICON(animate_seek_prev_frame,"animate_seek_prev_frame_icon."IMAGE_EXT,_("Seek to Previous Frame"));
 	INIT_STOCK_ICON(animate_play,"animate_play_icon."IMAGE_EXT,_("Play"));
 	INIT_STOCK_ICON(animate_stop,"animate_stop_icon."IMAGE_EXT,_("Stop"));
 	INIT_STOCK_ICON(animate_pause,"animate_pause_icon."IMAGE_EXT,_("Pause"));
-	INIT_STOCK_ICON(animate_seek_next_frame,"animate_seek_next_frame_icon."IMAGE_EXT,_("Next frame"));
-	INIT_STOCK_ICON(animate_seek_next_keyframe,"animate_seek_next_keyframe_icon."IMAGE_EXT,_("Next keyframe"));
-	INIT_STOCK_ICON(animate_seek_end,"animate_seek_end_icon."IMAGE_EXT,_("Seek to end"));
+	INIT_STOCK_ICON(animate_seek_next_frame,"animate_seek_next_frame_icon."IMAGE_EXT,_("Seek to Next frame"));
+	INIT_STOCK_ICON(animate_seek_next_keyframe,"animate_seek_next_keyframe_icon."IMAGE_EXT,_("Seek to Next Keyframe"));
+	INIT_STOCK_ICON(animate_seek_end,"animate_seek_end_icon."IMAGE_EXT,_("Seek to End"));
 	INIT_STOCK_ICON(animate_loop,"animate_loop_icon."IMAGE_EXT,_("Animate Loop"));
 
 	INIT_STOCK_ICON(add_to_group,"action_add_to_set_icon."IMAGE_EXT,_("Add Layer to Set"));
@@ -308,6 +313,8 @@ IconController::IconController(const synfig::String& /*basepath*/)
 
 	INIT_STOCK_ICON(toggle_show_grid,"show_grid_icon."IMAGE_EXT,_("Toggle show grid"));
 	INIT_STOCK_ICON(toggle_snap_grid,"snap_grid_icon."IMAGE_EXT,_("Toggle snap grid"));
+	INIT_STOCK_ICON(toggle_show_guide,"show_guide_icon."IMAGE_EXT,_("Toggle show guide"));
+	INIT_STOCK_ICON(toggle_snap_guide,"snap_guide_icon."IMAGE_EXT,_("Toggle snap guide"));
 
 	INIT_STOCK_ICON(toggle_onion_skin,"onion_skin_icon."IMAGE_EXT,_("Toggle onion skin"));
 
@@ -323,6 +330,8 @@ IconController::IconController(const synfig::String& /*basepath*/)
 	INIT_STOCK_ICON(interpolation_type_linear,"interpolation_type_linear_icon."IMAGE_EXT,_("Linear interpolation"));
 	INIT_STOCK_ICON(interpolation_type_clamped,"interpolation_type_clamped_icon."IMAGE_EXT,_("Clamped interpolation"));
 
+	INIT_STOCK_ICON(utils_chain_link_on,"utils_chain_link_on_icon."IMAGE_EXT,_("Linked"));
+	INIT_STOCK_ICON(utils_chain_link_off,"utils_chain_link_off_icon."IMAGE_EXT,_("Unlinked"));
 	INIT_STOCK_ICON(utils_timetrack_align,"utils_timetrack_align_icon."IMAGE_EXT,"Utils Timetrack align");
 
 	INIT_STOCK_ICON_CLONE(cvs_add,"gtk-add",_("CVS Add"));
@@ -335,33 +344,24 @@ IconController::IconController(const synfig::String& /*basepath*/)
 
 	icon_factory->add_default();
 
+	Gtk::IconSize::register_new("synfig-tiny_icon", 8, 8);
 	Gtk::IconSize::register_new("synfig-small_icon",12,12);
 	Gtk::IconSize::register_new("synfig-small_icon_16x16",16,16);
 
-	for(int i(0);i<(int)ValueBase::TYPE_END;i++)
-		_tree_pixbuf_table_value_type[i]=Gtk::Button().render_icon(value_icon(ValueBase::Type(i)),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+	for(Type *type = Type::get_first(); type != NULL; type = type->get_next())
+		_tree_pixbuf_table_value_type[type->identifier]=Gtk::Button().render_icon_pixbuf(value_icon(*type),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 
 	for(int i(0);i<((int)INTERPOLATION_CLAMPED+1);i++)
-		_tree_pixbuf_table_interpolation[i]=Gtk::Button().render_icon(interpolation_icon(Interpolation(i)),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+		_tree_pixbuf_table_interpolation[i]=Gtk::Button().render_icon_pixbuf(interpolation_icon(Interpolation(i)),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 }
 
-IconController::~IconController()
-{
-	for(int i(0);i<(int)ValueBase::TYPE_END;i++)
-		_tree_pixbuf_table_value_type[i]=Glib::RefPtr<Gdk::Pixbuf>();
-	for(int i(0);i<((int)INTERPOLATION_CLAMPED+1);i++)
-		_tree_pixbuf_table_interpolation[i]=Glib::RefPtr<Gdk::Pixbuf>();
-
-	icon_factory->remove_default();
-}
-
-Gdk::Cursor
+Glib::RefPtr<Gdk::Cursor>
 IconController::get_normal_cursor()
 {
-	return Gdk::Cursor(Gdk::TOP_LEFT_ARROW);
+	return Gdk::Cursor::create(Gdk::TOP_LEFT_ARROW);
 }
 
-Gdk::Cursor
+Glib::RefPtr<Gdk::Cursor>
 IconController::get_tool_cursor(const Glib::ustring& name,const Glib::RefPtr<Gdk::Window>& window)
 {
 	//this function is never called
@@ -369,90 +369,42 @@ IconController::get_tool_cursor(const Glib::ustring& name,const Glib::RefPtr<Gdk
 	assert(0);
 	// \todo Do we still need it?
 
-	Glib::RefPtr<Gdk::Pixmap> pixmap;
-	pixmap=Gdk::Pixmap::create(window, 64, 64, 8);
-	pixmap->set_colormap(window->get_colormap());
-	//pixmap->set_colormap(Gdk::Colormap::create(pixmap->get_visual(),false));
-	Glib::RefPtr<Gdk::Pixbuf> pixbuf;
-	pixbuf=Gtk::Button().render_icon(Gtk::StockID("synfig-"+name),Gtk::ICON_SIZE_SMALL_TOOLBAR);
-
-	pixbuf->render_to_drawable_alpha(
-		pixmap,
-		0,0,	// SOURCE X,Y
-		0,0,	// DEST X Y
-		-1,-1,	// WIDTH HEIGHT
-		Gdk::PIXBUF_ALPHA_FULL,	// (ignored)
-		64,		//int alpha_threshold,
-		Gdk::RGB_DITHER_MAX,		//RgbDither dither,
-		2,2	//int x_dither, int y_dither
-	);
-/*
-	pixmap->draw_pixbuf(
-		Glib::RefPtr<const Gdk::GC>(0),	// GC
-		pixbuf,
-		0, 0, // Source X,Y
-		0, 0, // Dest X,Y
-		-1, -1, // Width, Height
-		Gdk::RGB_DITHER_MAX, // Dither
-		0,0 // Dither X,Y
-	);
-*/
-
-	Gdk::Color FG("#000000");
-	Gdk::Color BG("#FF00FF");
-
-  	return Gdk::Cursor(pixmap, pixmap, FG, BG, 0, 0);
+	Glib::RefPtr<Gdk::Pixbuf> pixbuf =
+		Gtk::Button().render_icon_pixbuf(Gtk::StockID("synfig-"+name),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+  	return Gdk::Cursor::create(window->get_display(), pixbuf, 0, 0);
 }
 
 Gtk::StockID
-studio::value_icon(synfig::ValueBase::Type type)
+studio::value_icon(Type &type)
 {
-		switch(type)
-		{
-		case ValueBase::TYPE_BOOL:
-			return Gtk::StockID("synfig-type_bool");
-			break;
-		case ValueBase::TYPE_INTEGER:
-			return Gtk::StockID("synfig-type_integer");
-			break;
-		case ValueBase::TYPE_ANGLE:
-			return Gtk::StockID("synfig-type_angle");
-			break;
-		case ValueBase::TYPE_TIME:
-			return Gtk::StockID("synfig-type_time");
-			break;
-		case ValueBase::TYPE_REAL:
-			return Gtk::StockID("synfig-type_real");
-			break;
-		case ValueBase::TYPE_VECTOR:
-			return Gtk::StockID("synfig-type_vector");
-			break;
-		case ValueBase::TYPE_COLOR:
-			return Gtk::StockID("synfig-type_color");
-			break;
-		case ValueBase::TYPE_SEGMENT:
-			return Gtk::StockID("synfig-type_segment");
-			break;
-		case ValueBase::TYPE_BLINEPOINT:
-			return Gtk::StockID("synfig-type_blinepoint");
-			break;
-		case ValueBase::TYPE_LIST:
-			return Gtk::StockID("synfig-type_list");
-			break;
-		case ValueBase::TYPE_CANVAS:
-			return Gtk::StockID("synfig-type_canvas");
-			break;
-		case ValueBase::TYPE_STRING:
-			return Gtk::StockID("synfig-type_string");
-			break;
-		case ValueBase::TYPE_GRADIENT:
-			return Gtk::StockID("synfig-type_gradient");
-			break;
-		case ValueBase::TYPE_NIL:
-		default:
-			return Gtk::StockID("synfig-unknown");
-			break;
-		}
+	if (type == type_bool)
+		return Gtk::StockID("synfig-type_bool");
+	if (type == type_integer)
+		return Gtk::StockID("synfig-type_integer");
+	if (type == type_angle)
+		return Gtk::StockID("synfig-type_angle");
+	if (type == type_time)
+		return Gtk::StockID("synfig-type_time");
+	if (type == type_real)
+		return Gtk::StockID("synfig-type_real");
+	if (type == type_vector)
+		return Gtk::StockID("synfig-type_vector");
+	if (type == type_color)
+		return Gtk::StockID("synfig-type_color");
+	if (type == type_segment)
+		return Gtk::StockID("synfig-type_segment");
+	if (type == type_bline_point)
+		return Gtk::StockID("synfig-type_blinepoint");
+	if (type == type_list)
+		return Gtk::StockID("synfig-type_list");
+	if (type == type_canvas)
+		return Gtk::StockID("synfig-type_canvas");
+	if (type == type_string)
+		return Gtk::StockID("synfig-type_string");
+	if (type == type_gradient)
+		return Gtk::StockID("synfig-type_gradient");
+
+	return Gtk::StockID("synfig-unknown");
 }
 
 Gtk::StockID
@@ -462,26 +414,21 @@ studio::interpolation_icon(synfig::Interpolation type)
 	{
 		case INTERPOLATION_TCB:
 			return Gtk::StockID("synfig-interpolation_type_tcb");
-			break;
 		case INTERPOLATION_CONSTANT:
 			return Gtk::StockID("synfig-interpolation_type_const");
-			break;
 		case INTERPOLATION_LINEAR:
 			return Gtk::StockID("synfig-interpolation_type_linear");
-			break;
 		case INTERPOLATION_HALT:
 			return Gtk::StockID("synfig-interpolation_type_ease");
-			break;
 		case INTERPOLATION_CLAMPED:
 			return Gtk::StockID("synfig-interpolation_type_clamped");
-			break;
 		case INTERPOLATION_MANUAL:
 		case INTERPOLATION_UNDEFINED:
 		case INTERPOLATION_NIL:
 		default:
-			return Gtk::StockID();
 			break;
 	}
+	return Gtk::StockID();
 }
 
 
@@ -499,10 +446,10 @@ studio::valuenode_icon(etl::handle<synfig::ValueNode> value_node)
 }
 
 Glib::RefPtr<Gdk::Pixbuf>
-studio::get_tree_pixbuf(synfig::ValueBase::Type type)
+studio::get_tree_pixbuf(Type &type)
 {
-	//return Gtk::Button().render_icon(value_icon(type),Gtk::ICON_SIZE_SMALL_TOOLBAR);
-	return _tree_pixbuf_table_value_type[int(type)];
+	//return Gtk::Button().render_icon_pixbuf(value_icon(type),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+	return _tree_pixbuf_table_value_type[type.identifier];
 }
 
 Glib::RefPtr<Gdk::Pixbuf>
@@ -616,7 +563,7 @@ studio::layer_icon(const synfig::String &layer)
 	else if(layer=="noise")
 		return Gtk::StockID("synfig-layer_gradient_noise");
 	else if(layer=="linear_gradient")
-		return Gtk::StockID("synfig-layer_gradient_lineal");
+		return Gtk::StockID("synfig-layer_gradient_linear");
 	else if(layer=="radial_gradient")
 		return Gtk::StockID("synfig-layer_gradient_radial");
 	else if(layer=="spiral_gradient")
@@ -626,7 +573,7 @@ studio::layer_icon(const synfig::String &layer)
 		return Gtk::StockID("synfig-layer_other_duplicate");
 	else if(layer=="importimage" || layer=="import")
 		return Gtk::StockID("synfig-layer_other_importimage");
-	else if(layer=="PasteCanvas" || layer=="pastecanvas" || layer=="paste_canvas")
+	else if(layer=="group" || layer=="PasteCanvas" || layer=="pastecanvas" || layer=="paste_canvas")
 		return Gtk::StockID("synfig-layer_other_pastecanvas");
 	else if(layer=="plant")
 		return Gtk::StockID("synfig-layer_other_plant");
@@ -636,8 +583,12 @@ studio::layer_icon(const synfig::String &layer)
 		return Gtk::StockID("synfig-layer_other_skeleton");
 	else if(layer=="super_sample")
 		return Gtk::StockID("synfig-layer_other_supersample");
+	else if(layer=="switch")
+		return Gtk::StockID("synfig-layer_other_switch");
 	else if(layer=="text")
 		return Gtk::StockID("synfig-layer_other_text");
+	else if(layer=="sound")
+		return Gtk::StockID("synfig-layer_other_sound");
 	else if(layer=="timeloop")
 		return Gtk::StockID("synfig-layer_other_timeloop");
 	else if(layer=="xor_pattern")
@@ -661,6 +612,6 @@ studio::layer_icon(const synfig::String &layer)
 Glib::RefPtr<Gdk::Pixbuf>
 studio::get_tree_pixbuf_layer(const synfig::String &layer)
 {
-	return Gtk::Button().render_icon(layer_icon(layer),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+	return Gtk::Button().render_icon_pixbuf(layer_icon(layer),Gtk::ICON_SIZE_SMALL_TOOLBAR);
 }
 
