@@ -31,9 +31,6 @@
 #	include <config.h>
 #endif
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/entry.h>
-
 #include <synfig/valuenode_dynamiclist.h>
 #include <synfigapp/action_system.h>
 #include <synfig/valuenode_bline.h>
@@ -47,10 +44,11 @@
 #include <synfigapp/action.h>
 #include "event_mouse.h"
 #include "event_layerclick.h"
-#include "toolbox.h"
+#include "docks/dock_toolbox.h"
 #include "docks/dialog_tooloptions.h"
-#include <gtkmm/optionmenu.h>
 #include "duck.h"
+#include "widgets/widget_enum.h"
+#include "widgets/widget_distance.h"
 #include <synfigapp/main.h>
 
 #include "general.h"
@@ -66,6 +64,29 @@ using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
+#ifndef LAYER_CREATION
+#define LAYER_CREATION(button, stockid, tooltip)	\
+	{ \
+		Gtk::Image *icon = manage(new Gtk::Image(Gtk::StockID(stockid), \
+			Gtk::ICON_SIZE_SMALL_TOOLBAR)); \
+		button.add(*icon); \
+	} \
+	button.set_relief(Gtk::RELIEF_NONE); \
+	button.set_tooltip_text(tooltip); \
+	button.signal_toggled().connect(sigc::mem_fun(*this, \
+		&studio::StateRectangle_Context::toggle_layer_creation))
+#endif
+
+// indentation for options layout
+#ifndef SPACING
+#define SPACING(name, px) \
+	Gtk::Alignment *name = Gtk::manage(new Gtk::Alignment()); \
+	name->set_size_request(px)
+#endif
+
+#define GAP	(3)
+#define INDENTATION (6)
+
 /* === G L O B A L S ======================================================= */
 
 StateRectangle studio::state_rectangle;
@@ -90,24 +111,57 @@ class studio::StateRectangle_Context : public sigc::trackable
 	//Toolbox settings
 	synfigapp::Settings& settings;
 
-	//Toolbox display
+	// holder of options
 	Gtk::Table options_table;
 
-	Gtk::Entry		entry_id; //what to name the layer
+	// title
+	Gtk::Label title_label;
 
-	Gtk::Adjustment	adj_expand;
-	Gtk::Adjustment	adj_feather;
-	Gtk::SpinButton	spin_expand;
-	Gtk::SpinButton	spin_feather;
+	// layer name:
+	Gtk::Label id_label;
+	Gtk::HBox id_box;
+	Gtk::Entry id_entry;
 
-	Gtk::CheckButton checkbutton_invert;
-	Gtk::CheckButton checkbutton_layer_rectangle;
-	Gtk::CheckButton checkbutton_layer_region;
-	Gtk::CheckButton checkbutton_layer_outline;
-	Gtk::CheckButton checkbutton_layer_advanced_outline;
-	Gtk::CheckButton checkbutton_layer_curve_gradient;
-	Gtk::CheckButton checkbutton_layer_plant;
-	Gtk::CheckButton checkbutton_layer_link_origins;
+	// layer types to create:
+	Gtk::Label layer_types_label;
+	Gtk::ToggleButton layer_rectangle_togglebutton;
+	Gtk::ToggleButton layer_region_togglebutton;
+	Gtk::ToggleButton layer_outline_togglebutton;
+	Gtk::ToggleButton layer_advanced_outline_togglebutton;
+	Gtk::ToggleButton layer_curve_gradient_togglebutton;
+	Gtk::ToggleButton layer_plant_togglebutton;
+	Gtk::HBox layer_types_box;
+
+	// blend method
+	Gtk::Label blend_label;
+	Gtk::HBox blend_box;
+	Widget_Enum blend_enum;
+
+	// opacity
+	Gtk::Label opacity_label;
+	Gtk::HScale opacity_hscl;
+
+	// brush size
+	Gtk::Label bline_width_label;
+	Widget_Distance bline_width_dist;
+
+	// invert
+	Gtk::Label invert_label;
+	Gtk::CheckButton invert_checkbutton;
+	Gtk::HBox invert_box;
+
+	// feather size
+	Gtk::Label feather_label;
+	Widget_Distance feather_dist;
+
+	// expansion
+	Gtk::Label expand_label;
+	Widget_Distance expand_dist;
+
+	// link origins
+	Gtk::Label link_origins_label;
+	Gtk::CheckButton layer_link_origins_checkbutton;
+	Gtk::HBox link_origins_box;
 
 public:
 
@@ -123,38 +177,69 @@ public:
 			get_layer_plant_flag();
 	}
 
-	synfig::String get_id()const { return entry_id.get_text(); }
-	void set_id(const synfig::String& x) { return entry_id.set_text(x); }
+	synfig::String get_id()const { return id_entry.get_text(); }
+	void set_id(const synfig::String& x) { return id_entry.set_text(x); }
 
-	Real get_expand()const { return adj_expand.get_value(); }
-	void set_expand(Real f) { adj_expand.set_value(f); }
+	int get_blend()const { return blend_enum.get_value(); }
+	void set_blend(int x) { return blend_enum.set_value(x); }
 
-	Real get_feather()const { return adj_feather.get_value(); }
-	void set_feather(Real f) { adj_feather.set_value(f); }
+	Real get_opacity()const { return opacity_hscl.get_value(); }
+	void set_opacity(Real x) { opacity_hscl.set_value(x); }
 
-	bool get_invert()const { return checkbutton_invert.get_active(); }
-	void set_invert(bool i) { checkbutton_invert.set_active(i); }
+	Real get_bline_width() const {
+		return bline_width_dist.get_value().get(
+			Distance::SYSTEM_UNITS,
+			get_canvas_view()->get_canvas()->rend_desc()
+		);
+	}
+	void set_bline_width(Distance x) { return bline_width_dist.set_value(x);}
 
-	bool get_layer_rectangle_flag()const { return checkbutton_layer_rectangle.get_active(); }
-	void set_layer_rectangle_flag(bool x) { return checkbutton_layer_rectangle.set_active(x); }
+	Real get_feather_size() const {
+		return feather_dist.get_value().get(
+			Distance::SYSTEM_UNITS,
+			get_canvas_view()->get_canvas()->rend_desc()
+		);
+	}
+	void set_feather_size(Distance x) { return feather_dist.set_value(x);}
 
-	bool get_layer_region_flag()const { return checkbutton_layer_region.get_active(); }
-	void set_layer_region_flag(bool x) { return checkbutton_layer_region.set_active(x); }
+	Real get_expand_size() const {
+		return expand_dist.get_value().get(
+			Distance::SYSTEM_UNITS,
+			get_canvas_view()->get_canvas()->rend_desc()
+		);
+	}
+	void set_expand_size(Distance x) { return expand_dist.set_value(x);}
 
-	bool get_layer_outline_flag()const { return checkbutton_layer_outline.get_active(); }
-	void set_layer_outline_flag(bool x) { return checkbutton_layer_outline.set_active(x); }
+	bool get_invert()const { return invert_checkbutton.get_active(); }
+	void set_invert(bool i) { invert_checkbutton.set_active(i); }
 
-	bool get_layer_advanced_outline_flag()const { return checkbutton_layer_advanced_outline.get_active(); }
-	void set_layer_advanced_outline_flag(bool x) { return checkbutton_layer_advanced_outline.set_active(x); }
+	bool get_layer_rectangle_flag()const { return layer_rectangle_togglebutton.get_active(); }
+	void set_layer_rectangle_flag(bool x) { return layer_rectangle_togglebutton.set_active(x); }
 
-	bool get_layer_curve_gradient_flag()const { return checkbutton_layer_curve_gradient.get_active(); }
-	void set_layer_curve_gradient_flag(bool x) { return checkbutton_layer_curve_gradient.set_active(x); }
+	bool get_layer_region_flag()const { return layer_region_togglebutton.get_active(); }
+	void set_layer_region_flag(bool x) { return layer_region_togglebutton.set_active(x); }
 
-	bool get_layer_plant_flag()const { return checkbutton_layer_plant.get_active(); }
-	void set_layer_plant_flag(bool x) { return checkbutton_layer_plant.set_active(x); }
+	bool get_layer_outline_flag()const { return layer_outline_togglebutton.get_active(); }
+	void set_layer_outline_flag(bool x) { return layer_outline_togglebutton.set_active(x); }
 
-	bool get_layer_link_origins_flag()const { return checkbutton_layer_link_origins.get_active(); }
-	void set_layer_link_origins_flag(bool x) { return checkbutton_layer_link_origins.set_active(x); }
+	bool get_layer_advanced_outline_flag()const { return layer_advanced_outline_togglebutton.get_active(); }
+	void set_layer_advanced_outline_flag(bool x) { return layer_advanced_outline_togglebutton.set_active(x); }
+
+	bool get_layer_curve_gradient_flag()const { return layer_curve_gradient_togglebutton.get_active(); }
+	void set_layer_curve_gradient_flag(bool x) { return layer_curve_gradient_togglebutton.set_active(x); }
+
+	bool get_layer_plant_flag()const { return layer_plant_togglebutton.get_active(); }
+	void set_layer_plant_flag(bool x) { return layer_plant_togglebutton.set_active(x); }
+
+	bool get_layer_link_origins_flag()const { return layer_link_origins_checkbutton.get_active(); }
+	void set_layer_link_origins_flag(bool x) { return layer_link_origins_checkbutton.set_active(x); }
+
+  bool layer_rectangle_flag;
+  bool layer_region_flag;
+  bool layer_outline_flag;
+  bool layer_advanced_outline_flag;
+  bool layer_curve_gradient_flag;
+  bool layer_plant_flag;
 
 	void refresh_tool_options(); //to refresh the toolbox
 
@@ -189,6 +274,8 @@ public:
 
 	void make_rectangle(const Point& p1, const Point& p2);
 
+	void toggle_layer_creation();
+
 };	// END of class StateGradient_Context
 
 /* === M E T H O D S ======================================================= */
@@ -224,15 +311,30 @@ StateRectangle_Context::load_settings()
 		else
 			set_id("Rectangle");
 
-		if(settings.get_value("rectangle.expand",value))
-			set_expand(atof(value.c_str()));
+		if(settings.get_value("rectangle.blend",value) && value != "")
+			set_blend(atoi(value.c_str()));
 		else
-			set_expand(0);
+			set_blend(0);//(int)Color::BLEND_COMPOSITE); //0 should be blend composites value
+
+		if(settings.get_value("rectangle.opacity",value))
+			set_opacity(atof(value.c_str()));
+		else
+			set_opacity(1);
+
+		if(settings.get_value("rectangle.bline_width",value) && value != "")
+			set_bline_width(Distance(atof(value.c_str()), App::distance_system));
+		else
+			set_bline_width(Distance(1, App::distance_system)); // default width
+
+		if(settings.get_value("rectangle.expand",value))
+			set_expand_size(Distance(atof(value.c_str()), App::distance_system));
+		else
+			set_expand_size(Distance(0, App::distance_system)); // default expansion
 
 		if(settings.get_value("rectangle.feather",value))
-			set_feather(atof(value.c_str()));
+			set_feather_size(Distance(atof(value.c_str()), App::distance_system));
 		else
-			set_feather(0);
+			set_feather_size(Distance(0, App::distance_system)); // default feather
 
 		if(settings.get_value("rectangle.invert",value) && value != "0")
 			set_invert(true);
@@ -273,6 +375,14 @@ StateRectangle_Context::load_settings()
 			set_layer_link_origins_flag(false);
 		else
 			set_layer_link_origins_flag(true);
+
+	  // determine layer flags
+		layer_rectangle_flag = get_layer_rectangle_flag();
+	  layer_region_flag = get_layer_region_flag();
+	  layer_outline_flag = get_layer_outline_flag();
+	  layer_advanced_outline_flag = get_layer_outline_flag();
+	  layer_curve_gradient_flag = get_layer_curve_gradient_flag();
+	  layer_plant_flag = get_layer_plant_flag();
 	}
 	catch(...)
 	{
@@ -287,8 +397,11 @@ StateRectangle_Context::save_settings()
 	{
 		synfig::ChangeLocale change_locale(LC_NUMERIC, "C");
 		settings.set_value("rectangle.id",get_id().c_str());
-		settings.set_value("rectangle.expand",strprintf("%f",get_expand()));
-		settings.set_value("rectangle.feather",strprintf("%f",(float)get_feather()));
+		settings.set_value("rectangle.blend",strprintf("%d",get_blend()));
+		settings.set_value("rectangle.opacity",strprintf("%f",(float)get_opacity()));
+		settings.set_value("rectangle.bline_width", bline_width_dist.get_value().get_string());
+		settings.set_value("rectangle.expand",expand_dist.get_value().get_string());
+		settings.set_value("rectangle.feather", feather_dist.get_value().get_string());
 		settings.set_value("rectangle.invert",get_invert()?"1":"0");
 		settings.set_value("rectangle.layer_rectangle",get_layer_rectangle_flag()?"1":"0");
 		settings.set_value("rectangle.layer_outline",get_layer_outline_flag()?"1":"0");
@@ -361,45 +474,191 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 	duckmatic_push(get_work_area()),
 	prev_workarea_layer_status_(get_work_area()->get_allow_layer_clicks()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
-	entry_id(),
-	adj_expand(0,0,1,0.01,0.1),
-	adj_feather(0,0,1,0.01,0.1),
-	spin_expand(adj_expand,0.1,3),
-	spin_feather(adj_feather,0.1,3),
-	checkbutton_invert(_("Invert")),
-	checkbutton_layer_rectangle(_("Create Rectangle Layer")),
-	checkbutton_layer_region(_("Create Region")),
-	checkbutton_layer_outline(_("Create Outline")),
-	checkbutton_layer_advanced_outline(_("Create Advanced Outline")),
-	checkbutton_layer_curve_gradient(_("Create Curve Gradient")),
-	checkbutton_layer_plant(_("Create Plant")),
-	checkbutton_layer_link_origins(_("Link Spline Origins"))
+	opacity_hscl(0.0f, 1.01f, 0.01f)
 {
 	egress_on_selection_change=true;
+
+	/* Set up the tool options dialog */
+
+	// 0, title
+	title_label.set_label(_("Rectangle Creation"));
+	Pango::AttrList list;
+	Pango::AttrInt attr = Pango::Attribute::create_attr_weight(Pango::WEIGHT_BOLD);
+	list.insert(attr);
+	title_label.set_attributes(list);
+	title_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+
+	// 1, layer name label and entry
+	id_label.set_label(_("Name:"));
+	id_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+	SPACING(id_gap, GAP);
+	id_box.pack_start(id_label, Gtk::PACK_SHRINK);
+	id_box.pack_start(*id_gap, Gtk::PACK_SHRINK);
+
+	id_box.pack_start(id_entry);
+
+	// 2, layer types creation
+	layer_types_label.set_label(_("Create:"));
+	layer_types_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+
+	LAYER_CREATION(layer_rectangle_togglebutton,
+		("synfig-layer_geometry_rectangle"), _("Create a rectangle layer"));
+
+	LAYER_CREATION(layer_region_togglebutton,
+		("synfig-layer_geometry_region"), _("Create a region layer"));
+
+	LAYER_CREATION(layer_outline_togglebutton,
+		("synfig-layer_geometry_outline"), _("Create a outline layer"));
+
+	LAYER_CREATION(layer_advanced_outline_togglebutton,
+		("synfig-layer_geometry_advanced_outline"), _("Create a advanced outline layer"));
+
+	LAYER_CREATION(layer_plant_togglebutton,
+		("synfig-layer_other_plant"), _("Create a plant layer"));
+
+	LAYER_CREATION(layer_curve_gradient_togglebutton,
+		("synfig-layer_gradient_curve"), _("Create a gradient layer"));
+
+	SPACING(layer_types_indent, INDENTATION);
+
+	layer_types_box.pack_start(*layer_types_indent, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_rectangle_togglebutton, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_region_togglebutton, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_outline_togglebutton, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_advanced_outline_togglebutton, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_plant_togglebutton, Gtk::PACK_SHRINK);
+	layer_types_box.pack_start(layer_curve_gradient_togglebutton, Gtk::PACK_SHRINK);
+
+	// 3, blend method label and dropdown list
+	blend_label.set_label(_("Blend Method:"));
+	blend_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+	SPACING(blend_gap, GAP);
+	blend_box.pack_start(blend_label, Gtk::PACK_SHRINK);
+	blend_box.pack_start(*blend_gap, Gtk::PACK_SHRINK);
+
+	blend_enum.set_param_desc(ParamDesc(Color::BLEND_COMPOSITE,"blend_method")
+		.set_local_name(_("Blend Method"))
+		.set_description(_("Defines the blend method to be used for rectangles")));
+
+	// 4, opacity label and slider
+	opacity_label.set_label(_("Opacity:"));
+	opacity_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+
+	opacity_hscl.set_digits(2);
+	opacity_hscl.set_value_pos(Gtk::POS_LEFT);
+	opacity_hscl.set_tooltip_text(_("Opacity"));
+
+	// 5, bline width
+	bline_width_label.set_label(_("Brush Size:"));
+	bline_width_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+	bline_width_label.set_sensitive(false);
+
+	bline_width_dist.set_tooltip_text(_("Brush size"));
+	bline_width_dist.set_sensitive(false);
+
+	// 6, invert
+	invert_label.set_label(_("Invert"));
+	invert_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+
+	invert_box.pack_start(invert_label);
+	invert_box.pack_end(invert_checkbutton, Gtk::PACK_SHRINK);
+	invert_box.set_sensitive(false);
+
+	// 7, feather
+	feather_label.set_label(_("Feather:"));
+	feather_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+	feather_label.set_sensitive(false);
+
+	feather_dist.set_digits(2);
+	feather_dist.set_range(0,10000000);
+	feather_dist.set_sensitive(false);
+
+	// 8, expansion
+	expand_label.set_label(_("Expansion:"));
+	expand_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+	expand_label.set_sensitive(false);
+
+	expand_dist.set_digits(2);
+	expand_dist.set_range(0, 1000000);
+	expand_dist.set_sensitive(false);
+
+	// 9, link origins
+	link_origins_label.set_label(_("Link Origins"));
+	link_origins_label.set_alignment(Gtk::ALIGN_START, Gtk::ALIGN_CENTER);
+
+	link_origins_box.pack_start(link_origins_label);
+	link_origins_box.pack_end(layer_link_origins_checkbutton, Gtk::PACK_SHRINK);
+	link_origins_box.set_sensitive(false);
+
 	load_settings();
 
-	// Set up the tool options dialog
-	options_table.attach(*manage(new Gtk::Label(_("Rectangle Tool"))),	0, 2,  0,  1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(entry_id,										0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	// pack all options to the options_table
 
-	options_table.attach(checkbutton_layer_rectangle,					0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_outline,						0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_advanced_outline,			0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region,						0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_plant,						0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient,				0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_link_origins,				0, 2,  8,  9, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	// 0, title
+	options_table.attach(title_label,
+		0, 2, 0, 1, Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 1, name
+	options_table.attach(id_box,
+		0, 2, 1, 2, Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 2, layer types creation
+	options_table.attach(layer_types_label,
+		0, 2, 2, 3, Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(layer_types_box,
+		0, 2, 3, 4, Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 3, blend method
+	options_table.attach(blend_box,
+		0, 1, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(blend_enum,
+		1, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 4, opacity
+	options_table.attach(opacity_label,
+		0, 1, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(opacity_hscl,
+		1, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 5, brush size
+	options_table.attach(bline_width_label,
+		0, 1, 6, 7, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(bline_width_dist,
+		1, 2, 6, 7, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 6, invert
+	options_table.attach(invert_box,
+		0, 2, 7, 8, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 7, feather
+	options_table.attach(feather_label,
+		0, 1, 8, 9, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(feather_dist,
+		1, 2, 8, 9, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 8, expansion
+	options_table.attach(expand_label,
+		0, 1, 9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	options_table.attach(expand_dist,
+		1, 2, 9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::FILL, 0, 0
+		);
+	// 9, link origins
+	options_table.attach(link_origins_box,
+		0, 2, 10, 11, Gtk::FILL, Gtk::FILL, 0, 0
+		);
 
-	//invert flag
-   	options_table.attach(checkbutton_invert,   	   	   	   	   	   	   	0, 2,  9,  10, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-
-	//expand stuff
-   	options_table.attach(*manage(new Gtk::Label(_("Expansion:"))), 	   	0, 1,  10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_expand,									1, 2,  10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-
- 	//feather stuff
-	options_table.attach(*manage(new Gtk::Label(_("Feather:"))),		0, 1, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather,									1, 2, 11, 12, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	// fine-tune options layout
+	options_table.set_border_width(GAP*2); // border width
+	options_table.set_row_spacings(GAP); // row gap
+	options_table.set_row_spacing(0, GAP*2); // the gap between first and second row.
+	options_table.set_row_spacing(2, 1); // row gap between label and icon of layer type
+	options_table.set_row_spacing(11, 0); // the final row using border width of table
 
 	options_table.show_all();
 
@@ -417,7 +676,7 @@ StateRectangle_Context::StateRectangle_Context(CanvasView* canvas_view):
 
 	get_work_area()->set_cursor(Gdk::DOTBOX);
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 void
@@ -452,7 +711,7 @@ StateRectangle_Context::~StateRectangle_Context()
 
 	get_canvas_view()->queue_rebuild_ducks();
 
-	App::toolbox->refresh();
+	App::dock_toolbox->refresh();
 }
 
 Smach::event_result
@@ -499,7 +758,7 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	Real x_min, x_max, y_min, y_max;
 	if (p1[0] < p2[0]) { x_min = p1[0]; x_max = p2[0]; } else { x_min = p2[0]; x_max = p1[0]; }
 	if (p1[1] < p2[1]) { y_min = p1[1]; y_max = p2[1]; } else { y_min = p2[1]; y_max = p1[1]; }
-	x_min -= get_expand(); x_max += get_expand(); y_min -= get_expand(); y_max += get_expand();
+	x_min -= get_expand_size(); x_max += get_expand_size(); y_min -= get_expand_size(); y_max += get_expand_size();
 
 	std::vector<BLinePoint> new_list;
 	for (int i = 0; i < 4; i++)
@@ -534,7 +793,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 
 	if (get_layer_rectangle_flag())
 	{
+		egress_on_selection_change=false;
 		layer=get_canvas_interface()->add_layer_to("rectangle",canvas,depth);
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -549,12 +810,18 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		layer->set_param("point2",p2);
 		get_canvas_interface()->signal_layer_param_changed()(layer,"point2");
 
-		layer->set_param("expand",get_expand());
+		layer->set_param("expand",get_expand_size());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"expand");
 
 		layer->set_param("invert",get_invert());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"invert");
 
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
 		layer->set_description(get_id());
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 	}
@@ -567,7 +834,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	{
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
+		egress_on_selection_change=false;
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("curve_gradient",canvas,depth));
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -575,6 +844,16 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 			return;
 		}
 		layer_selection.push_back(layer);
+
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
+		layer->set_param("width",get_bline_width());
+		get_canvas_interface()->signal_layer_param_changed()(layer,"width");
+
 		layer->set_description(get_id()+_(" Gradient"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
@@ -629,7 +908,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	{
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
+		egress_on_selection_change=false;
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("plant",canvas,depth));
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -637,6 +918,13 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 			return;
 		}
 		layer_selection.push_back(layer);
+
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
 		layer->set_description(get_id()+_(" Plant"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
@@ -691,7 +979,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	{
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
+		egress_on_selection_change=false;
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("region",canvas,depth));
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -699,10 +989,17 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 			return;
 		}
 		layer_selection.push_back(layer);
+
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
 		layer->set_description(get_id()+_(" Region"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-		layer->set_param("feather",get_feather());
+		layer->set_param("feather",get_feather_size());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"feather");
 
 		layer->set_param("invert",get_invert());
@@ -763,7 +1060,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	{
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
 
+		egress_on_selection_change=false;
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("outline",canvas,depth));
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -774,7 +1073,16 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		layer->set_description(get_id()+_(" Outline"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-		layer->set_param("feather",get_feather());
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
+		layer->set_param("width",get_bline_width());
+		get_canvas_interface()->signal_layer_param_changed()(layer,"width");
+
+		layer->set_param("feather",get_feather_size());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"feather");
 
 		layer->set_param("invert",get_invert());
@@ -831,7 +1139,9 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 	if (get_layer_advanced_outline_flag())
 	{
 		synfigapp::PushMode push_mode(get_canvas_interface(),synfigapp::MODE_NORMAL);
+		egress_on_selection_change=false;
 		Layer::Handle layer(get_canvas_interface()->add_layer_to("advanced_outline",canvas,depth));
+		egress_on_selection_change=true;
 		if (!layer)
 		{
 			get_canvas_view()->get_ui_interface()->error(_("Unable to create layer"));
@@ -842,7 +1152,16 @@ StateRectangle_Context::make_rectangle(const Point& _p1, const Point& _p2)
 		layer->set_description(get_id()+_(" Advanced Outline"));
 		get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
-		layer->set_param("feather",get_feather());
+		layer->set_param("blend_method", get_blend());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "blend_method");
+
+		layer->set_param("amount", get_opacity());
+		get_canvas_interface()->signal_layer_param_changed()(layer, "amount");
+
+		layer->set_param("width",get_bline_width());
+		get_canvas_interface()->signal_layer_param_changed()(layer,"width");
+
+		layer->set_param("feather",get_feather_size());
 		get_canvas_interface()->signal_layer_param_changed()(layer,"feather");
 
 		layer->set_param("invert",get_invert());
@@ -950,3 +1269,96 @@ StateRectangle_Context::refresh_ducks()
 	get_work_area()->clear_ducks();
 	get_work_area()->queue_draw();
 }
+
+void
+StateRectangle_Context::toggle_layer_creation()
+{
+  // don't allow none layer creation
+  if (get_layer_rectangle_flag() +
+     get_layer_region_flag() +
+     get_layer_outline_flag() +
+     get_layer_advanced_outline_flag() +
+     get_layer_curve_gradient_flag() +
+     get_layer_plant_flag() == 0)
+  {
+    if(layer_rectangle_flag) set_layer_rectangle_flag(true);
+    else if(layer_region_flag) set_layer_region_flag(true);
+    else if(layer_outline_flag) set_layer_outline_flag(true);
+    else if(layer_advanced_outline_flag) set_layer_advanced_outline_flag(true);
+    else if(layer_curve_gradient_flag) set_layer_curve_gradient_flag(true);
+    else if(layer_plant_flag) set_layer_plant_flag(true);
+  }
+
+	// brush size
+	if (get_layer_outline_flag() ||
+		get_layer_advanced_outline_flag() ||
+		get_layer_curve_gradient_flag())
+	{
+		bline_width_label.set_sensitive(true);
+		bline_width_dist.set_sensitive(true);
+	}
+	else
+	{
+		bline_width_label.set_sensitive(false);
+		bline_width_dist.set_sensitive(false);
+	}
+
+	// invert
+	if (get_layer_rectangle_flag() ||
+		get_layer_region_flag() ||
+		get_layer_outline_flag() ||
+		get_layer_advanced_outline_flag())
+	{
+		invert_box.set_sensitive(true);
+	}
+	else
+		invert_box.set_sensitive(false);
+
+	// feather size
+	if (get_layer_rectangle_flag() ||
+		get_layer_rectangle_flag() ||
+		get_layer_region_flag() ||
+		get_layer_outline_flag() ||
+		get_layer_advanced_outline_flag())
+	{
+		feather_label.set_sensitive(true);
+		feather_dist.set_sensitive(true);
+	}
+	else
+	{
+		feather_label.set_sensitive(false);
+		feather_dist.set_sensitive(false);
+	}
+
+	// expansion
+	if (get_layer_rectangle_flag())
+	{
+
+		expand_label.set_sensitive(true);
+		expand_dist.set_sensitive(true);
+	}
+	else
+	{
+		expand_label.set_sensitive(false);
+		expand_dist.set_sensitive(false);
+	}
+
+	// link origins
+	if (get_layer_region_flag() +
+		get_layer_outline_flag() +
+		get_layer_advanced_outline_flag() +
+		get_layer_plant_flag() +
+		get_layer_curve_gradient_flag() >= 2)
+		{
+			link_origins_box.set_sensitive(true);
+		}
+	else link_origins_box.set_sensitive(false);
+
+  // update layer flags
+  layer_rectangle_flag = get_layer_rectangle_flag();
+  layer_region_flag = get_layer_region_flag();
+  layer_outline_flag = get_layer_outline_flag();
+  layer_advanced_outline_flag = get_layer_advanced_outline_flag();
+  layer_curve_gradient_flag = get_layer_curve_gradient_flag();
+  layer_plant_flag = get_layer_plant_flag();
+}
