@@ -107,7 +107,6 @@ ChildrenTree::ChildrenTree()
 		column->set_min_width(150);
 		column->set_sort_column(model.label);
 		tree_view.append_column(*column);
-
 	}
 	{	// --- T Y P E --------------------------------------------------------
 		int cols_count = tree_view.append_column(_("Type"),model.type);
@@ -167,7 +166,7 @@ ChildrenTree::ChildrenTree()
 
 	// Create a scrolled window for that tree
 	Gtk::ScrolledWindow *scroll_children_tree = manage(new class Gtk::ScrolledWindow());
-	scroll_children_tree->set_flags(Gtk::CAN_FOCUS);
+	scroll_children_tree->set_can_focus(true);
 	scroll_children_tree->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 	scroll_children_tree->add(tree_view);
 	scroll_children_tree->set_shadow_type(Gtk::SHADOW_ETCHED_IN);
@@ -243,7 +242,7 @@ ChildrenTree::set_model(Glib::RefPtr<ChildrenTreeStore> children_tree_store)
 }
 
 void
-ChildrenTree::set_time_adjustment(Gtk::Adjustment &adjustment)
+ChildrenTree::set_time_adjustment(const Glib::RefPtr<Gtk::Adjustment> &adjustment)
 {
 	cellrenderer_time_track->set_adjustment(adjustment);
 }
@@ -321,7 +320,7 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 			) break;
 			const Gtk::TreeRow row = *(tree_view.get_model()->get_iter(path));
 
-			if(column->get_first_cell_renderer()==cellrenderer_time_track)
+			if(column->get_first_cell()==cellrenderer_time_track)
 			{
 				Gdk::Rectangle rect;
 				tree_view.get_cell_area(path,*column,rect);
@@ -331,7 +330,7 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 				queue_draw_area(rect.get_x(),rect.get_y(),rect.get_width(),rect.get_height());
 				return true;
 			}
-			else if(column->get_first_cell_renderer()==cellrenderer_value)
+			else if(column->get_first_cell()==cellrenderer_value)
 				return signal_user_click()(event->button.button,row,COLUMNID_VALUE);
 			else
 				return signal_user_click()(event->button.button,row,COLUMNID_ID);
@@ -357,7 +356,7 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 
 			Gtk::TreeRow row = *(tree_view.get_model()->get_iter(path));
 
-			if(cellrenderer_time_track==column->get_first_cell_renderer())
+			if(cellrenderer_time_track==column->get_first_cell())
 			{
 				// Movement on TimeLine
 				Gdk::Rectangle rect;
@@ -389,7 +388,7 @@ ChildrenTree::on_tree_event(GdkEvent *event)
 
 			Gtk::TreeRow row = *(tree_view.get_model()->get_iter(path));
 
-			if(column && cellrenderer_time_track == column->get_first_cell_renderer())
+			if(column && cellrenderer_time_track == column->get_first_cell())
 			{
 				Gdk::Rectangle rect;
 				tree_view.get_cell_area(path,*column,rect);
