@@ -174,9 +174,11 @@ KeyframeTreeStore::KeyframeTreeStore(etl::loose_handle<synfigapp::CanvasInterfac
 	reset_stamp();
 	//reset_path_table();
 
+	//connect some events
 	canvas_interface()->signal_keyframe_added().connect(sigc::mem_fun(*this,&studio::KeyframeTreeStore::add_keyframe));
 	canvas_interface()->signal_keyframe_removed().connect(sigc::mem_fun(*this,&studio::KeyframeTreeStore::remove_keyframe));
 	canvas_interface()->signal_keyframe_changed().connect(sigc::mem_fun(*this,&studio::KeyframeTreeStore::change_keyframe));
+	//canvas_interface()->signal_keyframe_selected().connect(sigc::mem_fun(*this,&studio::KeyframeTreeStore::select_keyframe));
 }
 
 KeyframeTreeStore::~KeyframeTreeStore()
@@ -682,7 +684,7 @@ KeyframeTreeStore::get_path_vfunc (const iterator& gtk_iter)const
 
 	_keyframe_iterator *iter(static_cast<_keyframe_iterator*>(gtk_iter->gobj()->user_data));
 
-	path.append_index(iter->index);
+	path.push_back(iter->index);
 
 	return path;
 }
@@ -690,7 +692,7 @@ KeyframeTreeStore::get_path_vfunc (const iterator& gtk_iter)const
 bool
 KeyframeTreeStore::get_iter_vfunc (const Gtk::TreeModel::Path& path, iterator& iter)const
 {
-	if(path.get_depth()>=1)
+	if(path.size()>=1)
 		return iter_nth_root_child_vfunc(path.front(),iter);
 
 	// Error case
@@ -810,6 +812,16 @@ KeyframeTreeStore::find_row(const synfig::Keyframe &keyframe)
 	return row;
 }
 
+bool
+KeyframeTreeStore::find_keyframe_path(const synfig::Keyframe &keyframe, Gtk::TreeModel::Path &path)
+{
+	assert(keyframe);
+	Gtk::TreeRow row(find_row(keyframe));
+	path = get_path(row);
+
+	return true;
+}
+
 void
 KeyframeTreeStore::add_keyframe(synfig::Keyframe keyframe)
 {
@@ -829,6 +841,9 @@ KeyframeTreeStore::add_keyframe(synfig::Keyframe keyframe)
 	{
 		g_warning("%s", x.what());
 	}
+
+	// inform that something change around time to update the canvasview time widget color
+	canvas_interface()->signal_time_changed()();
 }
 
 void
@@ -863,6 +878,9 @@ KeyframeTreeStore::remove_keyframe(synfig::Keyframe keyframe)
 	{
 		g_warning("%s", x.what());
 	}
+
+	// inform that something change around time to update the canvasview time widget color
+	canvas_interface()->signal_time_changed()();
 }
 
 void
@@ -925,4 +943,7 @@ KeyframeTreeStore::change_keyframe(synfig::Keyframe keyframe)
 	{
 		g_warning("%s", x.what());
 	}
-}
\ No newline at end of file
+
+	// inform that something change around time to update the canvasview time widget color
+	canvas_interface()->signal_time_changed()();
+}
