@@ -95,7 +95,7 @@ using namespace studio;
 /* === M E T H O D S ======================================================= */
 
 LayerTree::LayerTree():
-	layer_amount_adjustment_(1,0,1,0.01,0.01,0)
+	layer_amount_adjustment_(Gtk::Adjustment::create(1,0,1,0.01,0.01,0))
 {
 	param_tree_view_=new Gtk::TreeView;
 	layer_tree_view_=new Gtk::TreeView;
@@ -120,9 +120,8 @@ LayerTree::LayerTree():
 	layer_amount_hscale->set_digits(2);
 	layer_amount_hscale->set_value_pos(Gtk::POS_LEFT);
 	layer_amount_hscale->set_sensitive(false);
-	layer_amount_hscale->set_update_policy( Gtk::UPDATE_DISCONTINUOUS);
 	attach(*layer_amount_hscale, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK, 1, 1);
-	layer_amount_adjustment_.signal_value_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_amount_value_changed));
+	layer_amount_adjustment_->signal_value_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_amount_value_changed));
 
 	Gtk::Image *icon;
 	//Gtk::IconSize iconsize(Gtk::IconSize::from_name("synfig-small_icon"));
@@ -169,7 +168,7 @@ LayerTree::LayerTree():
 
 	disable_amount_changed_signal=false;
 
-	blend_method_widget.set_param_desc(ParamDesc(Color::BlendMethod(),"blend_method"));
+	blend_method_widget.set_param_desc(ParamDesc((int)Color::BlendMethod(),"blend_method"));
 
 	blend_method_widget.set_value((int)Color::BLEND_COMPOSITE);
 	blend_method_widget.set_size_request(150,-1);
@@ -214,6 +213,7 @@ LayerTree::create_layer_tree()
 		column->pack_start(*cellrenderer,false);
 		column->add_attribute(cellrenderer->property_text(), layer_model.label);
 		column->add_attribute(cellrenderer->property_style(), layer_model.style);
+		column->add_attribute(cellrenderer->property_weight(), layer_model.weight);
 		cellrenderer->signal_edited().connect(sigc::mem_fun(*this, &studio::LayerTree::on_layer_renamed));
 		cellrenderer->property_editable()=true;
 
@@ -241,7 +241,7 @@ LayerTree::create_layer_tree()
 	get_layer_tree_view().set_search_column(layer_model.label);
 	get_layer_tree_view().set_search_equal_func(sigc::ptr_fun(&studio::LayerTreeStore::search_func));
 
-	std::list<Gtk::TargetEntry> listTargets;
+	std::vector<Gtk::TargetEntry> listTargets;
 	listTargets.push_back( Gtk::TargetEntry("LAYER") );
 	get_layer_tree_view().drag_dest_set(listTargets);
 
@@ -256,7 +256,7 @@ LayerTree::create_layer_tree()
 	get_layer_tree_view().show();
 
 	Gtk::ScrolledWindow *scroll = manage(new class Gtk::ScrolledWindow());
-	scroll->set_flags(Gtk::CAN_FOCUS);
+	scroll->set_can_focus(true);
 	scroll->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 	//scroll->add(get_layer_tree_view());
 	scroll->set_shadow_type(Gtk::SHADOW_ETCHED_IN);
@@ -309,13 +309,17 @@ LayerTree::create_param_tree()
 		// Set up the value-node icon cell-renderer to be on the far right
 		Gtk::CellRendererPixbuf* valuenode_icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 		column->pack_end(*valuenode_icon_cellrenderer,false);
-		valuenode_icon_cellrenderer->property_pixbuf()=Gtk::Button().render_icon(Gtk::StockID("synfig-value_node"),icon_size);
+		valuenode_icon_cellrenderer->property_pixbuf()=Gtk::Button().render_icon_pixbuf(Gtk::StockID("synfig-value_node"),icon_size);
 		column->add_attribute(valuenode_icon_cellrenderer->property_visible(), param_model.is_shared);
 
 		// Finish setting up the column
 		column->set_reorderable();
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
+		column->set_fixed_width(150);
+		column->set_min_width(75);
 		column->set_resizable();
 		column->set_clickable();
+		column->set_sort_column(param_model.name);
 
 		get_param_tree_view().append_column(*column);
 	}
@@ -335,9 +339,10 @@ LayerTree::create_param_tree()
 
 		// Finish setting up the column
 		get_param_tree_view().append_column(*column);
-		column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
+		column->set_fixed_width(150);
+		column->set_min_width(75);
 		column->set_clickable();
-		column->set_min_width(120);
 		column->set_reorderable();
 		column->set_resizable();
 	}
@@ -354,14 +359,15 @@ LayerTree::create_param_tree()
 		// Set up the static icon cell-renderer to be on the far right
 		Gtk::CellRendererPixbuf* static_icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 		column->pack_end(*static_icon_cellrenderer,false);
-		static_icon_cellrenderer->property_pixbuf()=Gtk::Button().render_icon(Gtk::StockID("synfig-valuenode_forbidanimation"),icon_size);
+		static_icon_cellrenderer->property_pixbuf()=Gtk::Button().render_icon_pixbuf(Gtk::StockID("synfig-valuenode_forbidanimation"),icon_size);
 		column->add_attribute(static_icon_cellrenderer->property_visible(), param_model.is_static);
 
 		// Finish setting up the column
 		get_param_tree_view().append_column(*column);
-		column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
-		column->set_clickable();
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
+		column->set_fixed_width(26);
 		column->set_min_width(26);
+		column->set_clickable();
 		column->set_reorderable();
 		column->set_resizable();
 	}
@@ -377,6 +383,9 @@ LayerTree::create_param_tree()
 		column->set_resizable();
 		column->set_clickable();
 		column->set_sort_column(param_model.type);
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
+		column->set_fixed_width(75);
+		column->set_min_width(50);
 	}
 #ifdef TIMETRACK_IN_PARAMS_PANEL
 	{	// --- T I M E   T R A C K --------------------------------------------
@@ -394,10 +403,10 @@ LayerTree::create_param_tree()
 
 		// Finish setting up the column
 		column->set_reorderable();
-		column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
+		column->set_fixed_width(200);
+		column->set_min_width(100);
 		column->set_resizable();
-// Commented during Align attempt
-//		column->set_min_width(200);
 
 		if (!getenv("SYNFIG_DISABLE_PARAMS_PANEL_TIMETRACK"))
 			get_param_tree_view().append_column(*column);
@@ -414,18 +423,12 @@ LayerTree::create_param_tree()
 	get_param_tree_view().signal_query_tooltip().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_view_query_tooltip));
 	// Column widget label event used to retrieve column size
 	Gtk::Widget* columnzero_label = get_param_tree_view().get_column(0)->get_widget ();
-	/* GTKMM 3 remplacement for columnzero_label signal_style_changed
-	columnzero_label->signal_style_updated().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_style_updated));
-	*/
-	columnzero_label->signal_style_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_style_changed));
-	/* GTKMM 3 remplacement for columnzero_label signal_expose_event
-	columnzero_label->signal_draw().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_draw));
-	*/
-	columnzero_label->signal_expose_event().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_expose_draw));
+	columnzero_label->signal_style_updated().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_column_label_tree_style_updated));
+	columnzero_label->signal_draw().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_column_label_tree_draw));
 	get_param_tree_view().show();
 
 	Gtk::ScrolledWindow *scroll = manage(new class Gtk::ScrolledWindow());
-	scroll->set_flags(Gtk::CAN_FOCUS);
+	scroll->set_can_focus(true);
 	scroll->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 	//scroll->add(get_param_tree_view());
 	scroll->set_shadow_type(Gtk::SHADOW_ETCHED_IN);
@@ -463,7 +466,7 @@ LayerTree::select_layer(synfig::Layer::Handle layer)
 			iter=sorted_layer_tree_store_->convert_child_iter_to_iter(iter);
 
 		Gtk::TreePath path(iter);
-		for(int i=path.get_depth();i;i--)
+		for(int i=(int)path.size();i;i--)
 		{
 			int j;
 			path=Gtk::TreePath(iter);
@@ -599,13 +602,13 @@ LayerTree::set_model(Glib::RefPtr<LayerTreeStore> layer_tree_store)
 }
 
 void
-LayerTree::set_time_adjustment(Gtk::Adjustment &adjustment)
+LayerTree::set_time_adjustment(const Glib::RefPtr<Gtk::Adjustment> &adjustment)
 {
 #ifdef TIMETRACK_IN_PARAMS_PANEL
 	cellrenderer_time_track->set_adjustment(adjustment);
 #endif	// TIMETRACK_IN_PARAMS_PANEL
-	adjustment.signal_value_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
-	adjustment.signal_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
+	adjustment->signal_value_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
+	adjustment->signal_changed().connect(sigc::mem_fun(get_param_tree_view(),&Gtk::TreeView::queue_draw));
 }
 
 void
@@ -616,7 +619,7 @@ LayerTree::on_dirty_preview()
 	{
 		layer_amount_hscale->set_sensitive(true);
 		disable_amount_changed_signal=true;
-		layer_amount_adjustment_.set_value(quick_layer->get_param("amount").get(Real()));
+		layer_amount_adjustment_->set_value(quick_layer->get_param("amount").get(Real()));
 		disable_amount_changed_signal=false;
 		if(quick_layer->get_param("blend_method").is_valid())
 		{
@@ -686,7 +689,7 @@ LayerTree::on_selection_changed()
 	{
 		layer_amount_hscale->set_sensitive(true);
 		disable_amount_changed_signal=true;
-		layer_amount_adjustment_.set_value(quick_layer->get_param("amount").get(Real()));
+		layer_amount_adjustment_->set_value(quick_layer->get_param("amount").get(Real()));
 		disable_amount_changed_signal=false;
 		if(quick_layer->get_param("blend_method").is_valid())
 		{
@@ -730,7 +733,7 @@ LayerTree::on_amount_value_changed()
 		return;
 
 	disable_amount_changed_signal=true;
-	signal_edited_value()(synfigapp::ValueDesc(quick_layer,"amount"),synfig::ValueBase(layer_amount_adjustment_.get_value()));
+	signal_edited_value()(synfigapp::ValueDesc(quick_layer,"amount"),synfig::ValueBase(layer_amount_adjustment_->get_value()));
 	disable_amount_changed_signal=false;
 }
 
@@ -815,11 +818,11 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 			const Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
-			if(column->get_first_cell_renderer()==cellrenderer_time_track)
+			if(column->get_first_cell()==cellrenderer_time_track)
 				return signal_layer_user_click()(event->button.button,row,COLUMNID_TIME_TRACK);
 			else
 #endif	// TIMETRACK_IN_PARAMS_PANEL
-			if(column->get_first_cell_renderer()==cellrenderer_value)
+			if(column->get_first_cell()==cellrenderer_value)
 				return signal_layer_user_click()(event->button.button,row,COLUMNID_VALUE);
 			else
 				return signal_layer_user_click()(event->button.button,row,COLUMNID_NAME);
@@ -846,7 +849,7 @@ LayerTree::on_layer_tree_event(GdkEvent *event)
 			//Gtk::TreeRow row = *(get_layer_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
-			if(cellrenderer_time_track==column->get_first_cell_renderer())
+			if(cellrenderer_time_track==column->get_first_cell())
 				// Movement on TimeLine
 				return true;
 			//else
@@ -892,7 +895,7 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 			const Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
-			if(column && column->get_first_cell_renderer()==cellrenderer_time_track)
+			if(column && column->get_first_cell()==cellrenderer_time_track)
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -930,7 +933,7 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 				}
 				else
 				{
-					if(column->get_first_cell_renderer()==cellrenderer_value)
+					if(column->get_first_cell()==cellrenderer_value)
 						return signal_param_user_click()(event->button.button,row,COLUMNID_VALUE);
 					else
 						return signal_param_user_click()(event->button.button,row,COLUMNID_NAME);
@@ -958,7 +961,7 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 			Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
-			if((event->motion.state&GDK_BUTTON1_MASK ||event->motion.state&GDK_BUTTON3_MASK) && column && cellrenderer_time_track==column->get_first_cell_renderer())
+			if(((event->motion.state&GDK_BUTTON1_MASK) || (event->motion.state&GDK_BUTTON3_MASK)) && column && cellrenderer_time_track==column->get_first_cell())
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -991,7 +994,7 @@ LayerTree::on_param_tree_event(GdkEvent *event)
 			Gtk::TreeRow row = *(get_param_tree_view().get_model()->get_iter(path));
 
 #ifdef TIMETRACK_IN_PARAMS_PANEL
-			if(column && cellrenderer_time_track==column->get_first_cell_renderer())
+			if(column && cellrenderer_time_track==column->get_first_cell())
 			{
 				Gdk::Rectangle rect;
 				get_param_tree_view().get_cell_area(path,*column,rect);
@@ -1301,41 +1304,21 @@ LayerTree::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
 }
 */
 
-// GTKMM 3 remplacement for on_param_tree_column_label_style_changed
-//void
-//LayerTree::on_param_tree_column_label_style_updated ()
-//{
-//	param_tree_style_changed = true;
-//}
-
 void
-LayerTree::on_param_tree_column_label_style_changed (const Glib::RefPtr< Gtk::Style >& /*previous_style*/)
+LayerTree::on_param_column_label_tree_style_updated()
 {
 	param_tree_style_changed = true;
 }
 
-// GTKMM 3 remplacement for on_param_tree_column_label_expose_draw
-//bool
-//LayerTree::on_param_tree_column_label_draw (const ::Cairo::RefPtr< ::Cairo::Context>& /*cr*/)
-//{
-//	if (param_tree_style_changed)
-//	{
-//		if (update_param_tree_header_height())	signal_param_tree_header_height_changed()(param_tree_header_height);
-//		param_tree_style_changed = false;
-//	}
-//	return true;
-//}
-
 bool
-LayerTree::on_param_tree_column_label_expose_draw (GdkEventExpose * /*event*/)
+LayerTree::on_param_column_label_tree_draw(const ::Cairo::RefPtr< ::Cairo::Context>& /*cr*/)
 {
 	if (param_tree_style_changed)
 	{
 		if (update_param_tree_header_height())	signal_param_tree_header_height_changed()(param_tree_header_height);
 		param_tree_style_changed = false;
 	}
-	//tell gtkmm to pass (x window) signal to the next signal handler
-	return false;
+	return true;
 }
 
 bool
