@@ -8,6 +8,7 @@
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007 Chris Moore
 **  Copyright (c) 2008 Paul Wise
+**  Copyright (c) 2015 Denis Zdorovtsov, Jerome Blanchi
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,6 +41,12 @@
 #include <algorithm>
 #include <gtkmm/notebook.h>
 #include <gtkmm/box.h>
+#include <gtkmm/widget.h>
+#include <gtkmm/colorselection.h>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <gdkmm/color.h>
+#include <climits>
 
 #include "general.h"
 
@@ -58,6 +65,8 @@ using namespace studio;
 #define ARROW_NEGATIVE_THRESHOLD 0.4
 
 /* === G L O B A L S ======================================================= */
+synfig::Gamma Widget_ColorEdit::hvs_gamma = synfig::Gamma(1.0/2.2);
+synfig::Gamma Widget_ColorEdit::hvs_gamma_in = synfig::Gamma(2.2);
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -66,7 +75,6 @@ using namespace studio;
 ColorSlider::ColorSlider(const ColorSlider::Type &x):
 	type(x)
 {
-	signal_expose_event().connect(sigc::mem_fun(*this, &ColorSlider::redraw));
 	set_size_request(-1,12);
 	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK);
 	add_events(Gdk::BUTTON1_MOTION_MASK);
@@ -115,13 +123,56 @@ ColorSlider::adjust_color(Type type, synfig::Color &color, float amount)
 	jump_table[int(type)](color,amount);
 }
 
-bool
-ColorSlider::redraw(GdkEventExpose */*bleh*/)
+void
+ColorSlider::draw_arrow(
+	const Cairo::RefPtr<Cairo::Context> &cr,
+	double x, double y,
+	double width, double height,
+	int size,
+	bool fill)
 {
-	//!Check if the window we want draw is ready
-	Glib::RefPtr<Gdk::Window> window = get_window();
-	if(!window) return false;
+	//TODO hardcoded colors
+	Color dark(0, 0, 0);
+	Color light(1, 1, 1);
 
+	//! Upper black pointing down arrow
+	cr->set_source_rgb(dark.get_r(), dark.get_g(), dark.get_b());
+	cr->set_line_width(1.0);
+	cr->move_to(x, y);
+	cr->line_to(x - 0.5*width, y - height);
+	cr->line_to(x + 0.5*width, y - height);
+	cr->close_path();
+	if (fill)
+	{
+/*		//! Draw on outline
+		cr->fill_preserve();
+		cr->set_source_rgb(light.get_r(), light.get_g(), light.get_b());
+		cr->stroke();
+*/
+		cr->fill();
+	}else cr->stroke();
+
+	//! Bottom light pointing up arrow
+	cr->set_source_rgb(light.get_r(), light.get_g(), light.get_b());
+	cr->set_line_width(1.0);
+	cr->move_to(x, size - height);
+	cr->line_to(x - 0.5*width, size);
+	cr->line_to(x + 0.5*width, size);
+	cr->close_path();
+	if (fill)
+	{
+/*		//! Draw on outline
+		cr->fill_preserve();
+		cr->set_source_rgb(dark.get_r(), dark.get_g(), dark.get_b());
+		cr->stroke();
+*/
+		cr->fill();
+	}else cr->stroke();
+}
+
+bool
+ColorSlider::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
+{
 	Color color(color_);
 
 	static const slider_color_func jump_table[int(TYPE_END)] =
@@ -161,7 +212,6 @@ ColorSlider::redraw(GdkEventExpose */*bleh*/)
 
 	Gdk::Rectangle ca(0,0,width,height);
 
-	Glib::RefPtr<Gdk::GC> gc(Gdk::GC::create(window));
 	const Color bg1(0.75, 0.75, 0.75);
 	const Color bg2(0.5, 0.5, 0.5);
 	int i;
@@ -171,49 +221,48 @@ ColorSlider::redraw(GdkEventExpose */*bleh*/)
 				   (use_colorspace_gamma() && type<TYPE_U)
 				   ? gamma_out(float(i)/float(width))
 				   :		  (float(i)/float(width)));
-		const Color c1(Color::blend(color,bg1,1.0).clamped());
-		const Color c2(Color::blend(color,bg2,1.0).clamped());
+		const Color c1(
+			colorconv_apply_gamma(
+				Color::blend(color,bg1,1.0).clamped() ));
+		const Color c2(
+			colorconv_apply_gamma(
+				Color::blend(color,bg2,1.0).clamped() ));
 		assert(c1.is_valid());
 		assert(c2.is_valid());
 
 		if((i*2/height)&1)
 		{
-			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
-			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
+	        cr->set_source_rgb(c1.get_r(), c1.get_g(), c1.get_b());
+	        cr->rectangle(ca.get_x()+i, ca.get_y(), 1, height/2);
+	        cr->fill();
 
-			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
-			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+	        cr->set_source_rgb(c2.get_r(), c2.get_g(), c2.get_b());
+	        cr->rectangle(ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+	        cr->fill();
 		}
 		else
 		{
-			gc->set_rgb_fg_color(colorconv_synfig2gdk(c2));
-			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y(), 1, height/2);
+	        cr->set_source_rgb(c2.get_r(), c2.get_g(), c2.get_b());
+	        cr->rectangle(ca.get_x()+i, ca.get_y(), 1, height/2);
+	        cr->fill();
 
-			gc->set_rgb_fg_color(colorconv_synfig2gdk(c1));
-			window->draw_rectangle(gc, true, ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+	        cr->set_source_rgb(c1.get_r(), c1.get_g(), c1.get_b());
+	        cr->rectangle(ca.get_x()+i, ca.get_y()+height/2, 1, height/2);
+	        cr->fill();
 		}
 	}
 
-	get_style()->paint_arrow(
-		window,
-		(orig_color.get_y()<ARROW_NEGATIVE_THRESHOLD)?Gtk::STATE_SELECTED:Gtk::STATE_ACTIVE,
-		//use light arrow on dark color, and dark arrow on light color , TODO: detect from style which is darkest from SELECTED or ACTIVE
-		Gtk::SHADOW_OUT,
-		ca,
-		*this,
-		" ",
-		Gtk::ARROW_UP,
-		1,
-		int(amount*width)-height/2,
-		0,
-		height,
-		height
-	);
+    cr->set_source_rgb(1, 1, 1);
+    cr->rectangle(ca.get_x()+1, ca.get_y()+1, width-3, height-3);
+    cr->stroke();
+
+    cr->set_source_rgb(0, 0, 0);
+    cr->rectangle(ca.get_x(), ca.get_y(), width-1, height-1);
+    cr->stroke();
+
+    //! Draw face to face contrasted arrows
+    draw_arrow(cr, (int(amount*width)), height/2, height/2, height/2, height, 1);
 
-	gc->set_rgb_fg_color(Gdk::Color("#ffffff"));
-	window->draw_rectangle(gc, false, ca.get_x()+1, ca.get_y()+1, width-3, height-3);
-	gc->set_rgb_fg_color(Gdk::Color("#000000"));
-	window->draw_rectangle(gc, false, ca.get_x(), ca.get_y(), width-1, height-1);
 	return true;
 }
 
@@ -290,26 +339,54 @@ ColorSlider::on_event(GdkEvent *event)
 }
 
 /* === M E T H O D S ======================================================= */
+void 
+Widget_ColorEdit::SliderRow(int i,ColorSlider * n, char * l, Pango::AttrList & attr_list, Gtk::Table* table)
+{
+	Gtk::Label *label;
+	n->signal_slider_moved().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_slider_moved));
+	//n->signal_activated().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::activated));
+	n->signal_activated().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
+	label=manage(new class Gtk::Label(l,0.0,0.5));
+	label->set_use_markup(false);
+	label->set_use_underline(false);
+	label->set_attributes(attr_list);
+	table->attach(*label, 0, 1, 1+2*i, 2+2*i, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	table->attach(*n, 0, 1, 2+2*i, 3+2*i, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+}
+
+void
+Widget_ColorEdit::AttachSpinButton(int i, Gtk::SpinButton * n, Gtk::Table * table)
+{
+	n->set_update_policy(Gtk::UPDATE_ALWAYS);
+	n->set_size_request(SPINBUTTON_WIDTH,-1);
+	n->show();
+	table->attach(*n, 1, 2, 1+2*i, 3+2*i, Gtk::SHRINK, Gtk::EXPAND, 2, 0);
+}
 
 Widget_ColorEdit::Widget_ColorEdit():
-	R_adjustment(0,-10000000,10000000,1,10,0),
-	G_adjustment(0,-10000000,10000000,1,10,0),
-	B_adjustment(0,-10000000,10000000,1,10,0),
-	A_adjustment(0,-10000000,10000000,1,10,0)
+	R_adjustment(Gtk::Adjustment::create(0,-10000000,10000000,1,10,0)),
+	G_adjustment(Gtk::Adjustment::create(0,-10000000,10000000,1,10,0)),
+	B_adjustment(Gtk::Adjustment::create(0,-10000000,10000000,1,10,0)),
+	A_adjustment(Gtk::Adjustment::create(0,-10000000,10000000,1,10,0)),
+	colorHVSChanged(false)
 {
 	notebook=manage(new Gtk::Notebook);
 
 	Gtk::Table* rgb_table(manage(new Gtk::Table()));
 	Gtk::Table* yuv_table(manage(new Gtk::Table()));
+	Gtk::Table* hvs_table(manage(new Gtk::Table()));
 	Gtk::Table* main_table(this);
 
 	{
 		Gtk::VBox* rgb_box(manage(new Gtk::VBox()));
 		Gtk::VBox* yuv_box(manage(new Gtk::VBox()));
+		Gtk::VBox* hvs_box(manage(new Gtk::VBox()));
 		rgb_box->pack_start(*rgb_table,false,false);
 		yuv_box->pack_start(*yuv_table,false,false);
+		hvs_box->pack_start(*hvs_table,false,false);
 		notebook->append_page(*rgb_box,_("RGB"));
 		notebook->append_page(*yuv_box,_("YUV"));
+		notebook->append_page(*hvs_box,_("HSV"));
 	}
 
 	color=Color(0,0,0,0);
@@ -317,12 +394,10 @@ Widget_ColorEdit::Widget_ColorEdit():
 	set_size_request(200,-1);
 	hold_signals=true;
 
-	Gtk::Label *label;
-
-	R_adjustment.set_lower(-10000000);
-	G_adjustment.set_lower(-10000000);
-	B_adjustment.set_lower(-10000000);
-	A_adjustment.set_lower(-10000000);
+	R_adjustment->set_lower(-10000000);
+	G_adjustment->set_lower(-10000000);
+	B_adjustment->set_lower(-10000000);
+	A_adjustment->set_lower(-10000000);
 
 	clamp_=true;
 
@@ -336,26 +411,13 @@ Widget_ColorEdit::Widget_ColorEdit():
 	attach(widget_color, 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	attach(*notebook, 0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
-#define SLIDER_ROW(i,n,l) \
-	slider_##n=manage(new ColorSlider(ColorSlider::TYPE_##n));	\
-	slider_##n->signal_slider_moved().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_slider_moved)); \
-	/*slider_##n->signal_activated().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::activated));*/ \
-	slider_##n->signal_activated().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed)); \
-	label=manage(new class Gtk::Label(l,0.0,0.5)); \
-	label->set_use_markup(false); \
-	label->set_use_underline(false); \
-	label->set_attributes(attr_list); \
-	table->attach(*label, 0, 1, 1+2*i, 2+2*i, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);	\
-	table->attach(*slider_##n, 0, 1, 2+2*i, 3+2*i, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0)
+	Gtk::Label *label;
 
-#define ATTACH_SPIN_BUTTON(i,n) \
-	spinbutton_##n=manage(new class Gtk::SpinButton(n##_adjustment,1,0)); \
-	spinbutton_##n->set_update_policy(Gtk::UPDATE_ALWAYS); \
-	spinbutton_##n->set_size_request(SPINBUTTON_WIDTH,-1); \
-	spinbutton_##n->show(); \
-	table->attach(*spinbutton_##n, 1, 2, 1+2*i, 3+2*i, Gtk::SHRINK, Gtk::EXPAND, 2, 0)
-
-	{
+	//This defines are used for code below simplification.
+	#define SLIDER_ROW(i,n,l) SliderRow(i, slider_##n = manage(new ColorSlider(ColorSlider::TYPE_##n)), l,attr_list,table);
+	#define ATTACH_SPIN_BUTTON(i,n) AttachSpinButton(i, spinbutton_##n = manage(new class Gtk::SpinButton(n##_adjustment, 1, 0)),table);
+	
+	{ //RGB frame
 		Gtk::Table* table(rgb_table);
 		SLIDER_ROW(0,R,_("Red"));
 		ATTACH_SPIN_BUTTON(0,R);
@@ -368,14 +430,15 @@ Widget_ColorEdit::Widget_ColorEdit():
 		hex_color_label->set_use_markup(false);
 		hex_color_label->set_use_underline(false);
 		hex_color_label->set_attributes(attr_list);
-		table->attach(*hex_color_label, 0, 1, 7, 8, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+		rgb_table->attach(*hex_color_label, 0, 1, 7, 8, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 
 		hex_color = manage(new Gtk::Entry());
 		hex_color->set_width_chars(8);
 		hex_color->signal_activate().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_hex_edited));
-		table->attach(*hex_color, 0, 1, 8, 9, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
+		hex_color->signal_focus_out_event().connect(sigc::mem_fun(*this, &studio::Widget_ColorEdit::on_hex_focus_out));
+		rgb_table->attach(*hex_color, 0, 1, 8, 9, Gtk::SHRINK, Gtk::SHRINK, 0, 0);
 	}
-	{
+	{ //YUM frame
 		Gtk::Table* table(yuv_table);
 		SLIDER_ROW(0,Y,_("Luma"));
 		SLIDER_ROW(1,HUE,_("Hue"));
@@ -383,6 +446,14 @@ Widget_ColorEdit::Widget_ColorEdit():
 		SLIDER_ROW(3,U,_("U"));
 		SLIDER_ROW(4,V,_("V"));
 	}
+	{ //HVS frame
+		//I use Gtk::ColorSelection widget here.
+		hvsColorWidget = manage(new Gtk::ColorSelection());
+		setHVSColor(get_value());
+		hvsColorWidget->signal_color_changed().connect(sigc::mem_fun(*this, &studio::Widget_ColorEdit::on_color_changed));
+		//TODO: Anybody knows how to set min size for this widget? I've tried use set_size_request(..). But it doesn't works.
+		hvs_table->attach(*(hvsColorWidget), 0, 1, 0, 1, Gtk::FILL, Gtk::FILL, 2, 2);
+	}
 	{
 		Gtk::Table* table(main_table);
 		SLIDER_ROW(1,A,_("Alpha"));
@@ -397,10 +468,10 @@ Widget_ColorEdit::Widget_ColorEdit():
 	spinbutton_B->signal_activate().connect(sigc::mem_fun(*spinbutton_A,&Gtk::SpinButton::grab_focus));
 	spinbutton_A->signal_activate().connect(sigc::mem_fun(*spinbutton_R,&Gtk::SpinButton::grab_focus));
 
-	R_adjustment.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
-	G_adjustment.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
-	B_adjustment.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
-	A_adjustment.signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
+	R_adjustment->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
+	G_adjustment->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
+	B_adjustment->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
+	A_adjustment->signal_value_changed().connect(sigc::mem_fun(*this,&studio::Widget_ColorEdit::on_value_changed));
 
 	show_all_children();
 
@@ -414,6 +485,41 @@ Widget_ColorEdit::~Widget_ColorEdit()
 {
 }
 
+#define CLIP_VALUE(value, min, max) (value <= min ? min : (value > max ? max : value))
+
+void Widget_ColorEdit::setHVSColor(synfig::Color color)
+{
+	Gdk::Color gtkColor;
+	float r = hvs_gamma.r_F32_to_F32(CLIP_VALUE(color.get_r(),0.0,1.0));
+	float g = hvs_gamma.g_F32_to_F32(CLIP_VALUE(color.get_g(),0.0,1.0));
+	float b = hvs_gamma.b_F32_to_F32(CLIP_VALUE(color.get_b(),0.0,1.0));
+	gtkColor.set_red((unsigned short)(r * USHRT_MAX));
+	gtkColor.set_green((unsigned short)(g * USHRT_MAX));
+	gtkColor.set_blue((unsigned short)(b * USHRT_MAX));
+	colorHVSChanged = true;
+	hvsColorWidget->set_previous_color (gtkColor); //We can't use it there, cause color changes in realtime.
+	hvsColorWidget->set_current_color (gtkColor);
+	colorHVSChanged = false;
+}
+
+void
+Widget_ColorEdit::on_color_changed()
+{ 
+	//Spike! Gtk::ColorSelection emits this signal when I use 
+	//set_current_color(...). It calls recursion. Used a flag to fix it.
+	if (!colorHVSChanged)
+	{
+		Gdk::Color newColor = hvsColorWidget->get_current_color();
+		float r = hvs_gamma_in.r_F32_to_F32((float)newColor.get_red() / USHRT_MAX);
+		float g = hvs_gamma_in.g_F32_to_F32((float)newColor.get_green() / USHRT_MAX);
+		float b = hvs_gamma_in.b_F32_to_F32((float)newColor.get_blue() / USHRT_MAX);
+		const synfig::Color synfigColor(r, g, b);
+		set_value(synfigColor);
+		colorHVSChanged = true; //I reset the flag in setHVSColor(..)
+		on_value_changed();
+	}
+}
+
 void
 Widget_ColorEdit::on_slider_moved(ColorSlider::Type type, float amount)
 {
@@ -449,6 +555,13 @@ Widget_ColorEdit::on_hex_edited()
 	signal_value_changed_();
 }
 
+bool
+Widget_ColorEdit::on_hex_focus_out(GdkEventFocus* /*event*/)
+{
+	on_hex_edited();
+	return true;
+}
+
 void
 Widget_ColorEdit::on_value_changed()
 {
@@ -457,6 +570,7 @@ Widget_ColorEdit::on_value_changed()
 
 	const Color color(get_value_raw());
 	assert(color.is_valid());
+	setHVSColor(color);
 	slider_R->set_color(color);
 	slider_G->set_color(color);
 	slider_B->set_color(color);
@@ -507,20 +621,20 @@ Widget_ColorEdit::set_value(const synfig::Color &data)
 	clamp_=false;
 
 	color=data;
-
+	
 	if(use_colorspace_gamma())
 	{
-		R_adjustment.set_value(gamma_in(color.get_r())*100);
-		G_adjustment.set_value(gamma_in(color.get_g())*100);
-		B_adjustment.set_value(gamma_in(color.get_b())*100);
+		R_adjustment->set_value(gamma_in(color.get_r())*100);
+		G_adjustment->set_value(gamma_in(color.get_g())*100);
+		B_adjustment->set_value(gamma_in(color.get_b())*100);
 	}
 	else
 	{
-		R_adjustment.set_value(color.get_r()*100);
-		G_adjustment.set_value(color.get_g()*100);
-		B_adjustment.set_value(color.get_b()*100);
+		R_adjustment->set_value(color.get_r()*100);
+		G_adjustment->set_value(color.get_g()*100);
+		B_adjustment->set_value(color.get_b()*100);
 	}
-	A_adjustment.set_value(color.get_a()*100);
+	A_adjustment->set_value(color.get_a()*100);
 
 	slider_R->set_color(color);
 	slider_G->set_color(color);
@@ -543,17 +657,17 @@ Widget_ColorEdit::get_value_raw()
 	Color color;
 	if(use_colorspace_gamma())
 	{
-		color.set_r(gamma_out(R_adjustment.get_value()/100.0f));
-		color.set_g(gamma_out(G_adjustment.get_value()/100.0f));
-		color.set_b(gamma_out(B_adjustment.get_value()/100.0f));
+		color.set_r(gamma_out(R_adjustment->get_value()/100.0f));
+		color.set_g(gamma_out(G_adjustment->get_value()/100.0f));
+		color.set_b(gamma_out(B_adjustment->get_value()/100.0f));
 	}
 	else
 	{
-		color.set_r(R_adjustment.get_value()/100);
-		color.set_g(G_adjustment.get_value()/100);
-		color.set_b(B_adjustment.get_value()/100);
+		color.set_r(R_adjustment->get_value()/100);
+		color.set_g(G_adjustment->get_value()/100);
+		color.set_b(B_adjustment->get_value()/100);
 	}
-	color.set_a(A_adjustment.get_value()/100);
+	color.set_a(A_adjustment->get_value()/100);
 	assert(color.is_valid());
 
 	return color;
@@ -564,19 +678,19 @@ Widget_ColorEdit::get_value()
 {
 	if(use_colorspace_gamma())
 	{
-		color.set_r(gamma_out(R_adjustment.get_value()/100.0f));
-		color.set_g(gamma_out(G_adjustment.get_value()/100.0f));
-		color.set_b(gamma_out(B_adjustment.get_value()/100.0f));
+		color.set_r(gamma_out(R_adjustment->get_value()/100.0f));
+		color.set_g(gamma_out(G_adjustment->get_value()/100.0f));
+		color.set_b(gamma_out(B_adjustment->get_value()/100.0f));
 		assert(color.is_valid());
 	}
 	else
 	{
-		color.set_r(R_adjustment.get_value()/100);
-		color.set_g(G_adjustment.get_value()/100);
-		color.set_b(B_adjustment.get_value()/100);
+		color.set_r(R_adjustment->get_value()/100);
+		color.set_g(G_adjustment->get_value()/100);
+		color.set_b(B_adjustment->get_value()/100);
 		assert(color.is_valid());
 	}
-	color.set_a(A_adjustment.get_value()/100);
+	color.set_a(A_adjustment->get_value()/100);
 	assert(color.is_valid());
 
 	if(notebook->get_current_page()!=0)
