@@ -34,6 +34,7 @@
 #include "valuenodelinkconnect.h"
 #include "valuenodereplace.h"
 #include "valuedescblinelink.h"
+#include "valuedescset.h"
 
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_const.h>
@@ -70,9 +71,10 @@ ACTION_SET_CVS_ID(Action::ValueDescBLineLink,"$Id$");
 
 /* === M E T H O D S ======================================================= */
 
-Action::ValueDescBLineLink::ValueDescBLineLink()
-{
-}
+Action::ValueDescBLineLink::ValueDescBLineLink():
+	origin(),
+	index()
+{ }
 
 Action::ParamVocab
 Action::ValueDescBLineLink::get_param_vocab()
@@ -187,17 +189,42 @@ Action::ValueDescBLineLink::prepare()
 
 		// parent is BLINEPOINT ValueNode
 		if (value_desc.parent_is_linkable_value_node() &&
-			value_desc.get_parent_value_node()->get_type() == ValueBase::TYPE_BLINEPOINT &&
+			value_desc.get_parent_value_node()->get_type() == type_bline_point &&
 			ValueNode_Composite::Handle::cast_dynamic(value_desc.get_parent_value_node()))
 		{
-			String link_name(synfig::LinkableValueNode::Handle::cast_reinterpret(value_desc.get_parent_value_node())->
-								link_name(value_desc.get_index()));
+			ValueNode_Composite::Handle composite = ValueNode_Composite::Handle::cast_dynamic(value_desc.get_parent_value_node());
+			String link_name(composite->link_name(value_desc.get_index()));
+
 			if (link_name == "t1" || link_name == "t2")
-				calculated_value_node = ValueNode_BLineCalcTangent::create(ValueBase::TYPE_VECTOR);
-			else if (link_name == "width")
-				calculated_value_node = ValueNode_BLineCalcWidth::create(ValueBase::TYPE_REAL);
-			else if (link_name == "point")
-				calculated_value_node = ValueNode_BLineCalcVertex::create(ValueBase::TYPE_VECTOR);
+			{
+				action = ValueDescSet::create();
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("value_desc",ValueDesc(composite,composite->get_link_index_from_name("split_radius")));
+				action->set_param("time",time);
+				action->set_param("new_value",synfig::ValueBase(true));
+				assert(action->is_ready());
+				if(!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
+				add_action(action);
+
+				action = ValueDescSet::create();
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("value_desc",ValueDesc(composite,composite->get_link_index_from_name("split_angle")));
+				action->set_param("time",time);
+				action->set_param("new_value",synfig::ValueBase(true));
+				assert(action->is_ready());
+				if(!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
+				add_action(action);
+
+				calculated_value_node = ValueNode_BLineCalcTangent::create(type_vector);
+			}
+			else
+			if (link_name == "width")
+				calculated_value_node = ValueNode_BLineCalcWidth::create(type_real);
+			else
+			if (link_name == "point")
+				calculated_value_node = ValueNode_BLineCalcVertex::create(type_vector);
 			else
 			{
 				synfig::warning("can't link '%s'", link_name.c_str());
@@ -210,21 +237,62 @@ Action::ValueDescBLineLink::prepare()
 		}
 		// BLINEPOINT ValueNode - link its vertex
 		else if (value_desc.is_value_node() &&
-				 value_desc.get_value_type() == ValueBase::TYPE_BLINEPOINT &&
+				 value_desc.get_value_type() == type_bline_point &&
 				 ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()))
 		{
-			calculated_value_node = ValueNode_BLineCalcVertex::create(ValueBase::TYPE_VECTOR);
+			ValueNode_Composite::Handle composite = ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node());
+			String link_name(value_desc.get_sub_name());
+			int index = composite->get_link_index_from_name(link_name);
+			calculated_value_node.reset();
+
+			if (link_name == "t1" || link_name == "t2")
+			{
+				action = ValueDescSet::create();
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("value_desc",ValueDesc(composite,composite->get_link_index_from_name("split_radius")));
+				action->set_param("time",time);
+				action->set_param("new_value",synfig::ValueBase(true));
+				assert(action->is_ready());
+				if(!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
+				add_action(action);
+
+				action = ValueDescSet::create();
+				action->set_param("canvas",get_canvas());
+				action->set_param("canvas_interface",get_canvas_interface());
+				action->set_param("value_desc",ValueDesc(composite,composite->get_link_index_from_name("split_angle")));
+				action->set_param("time",time);
+				action->set_param("new_value",synfig::ValueBase(true));
+				assert(action->is_ready());
+				if(!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
+				add_action(action);
+
+				calculated_value_node = ValueNode_BLineCalcTangent::create(type_vector);
+			}
+			else
+			if (link_name == "width")
+				calculated_value_node = ValueNode_BLineCalcWidth::create(type_real);
+			else
+			if (link_name == "point")
+				calculated_value_node = ValueNode_BLineCalcVertex::create(type_vector);
+
+			if (index < 0 || !calculated_value_node)
+			{
+				synfig::warning("can't link '%s'", link_name.c_str());
+				continue;
+			}
+
 			action = ValueNodeLinkConnect::create();
 			action->set_param("parent_value_node", value_desc.get_value_node());
-			action->set_param("index", 0); // index for 'vertex' in 'composite'
+			action->set_param("index", index);
 		}
 		// exported ValueNode
 		else if (value_desc.parent_is_canvas())
 		{
-			if (value_desc.get_value_type() == ValueBase::TYPE_VECTOR)
-				calculated_value_node = ValueNode_BLineCalcVertex::create(ValueBase::TYPE_VECTOR);
-			else if (value_desc.get_value_type() == ValueBase::TYPE_REAL)
-				calculated_value_node = ValueNode_BLineCalcWidth::create(ValueBase::TYPE_REAL);
+			if (value_desc.get_value_type() == type_vector)
+				calculated_value_node = ValueNode_BLineCalcVertex::create(type_vector);
+			else if (value_desc.get_value_type() == type_real)
+				calculated_value_node = ValueNode_BLineCalcWidth::create(type_real);
 			else
 				continue;
 
@@ -245,17 +313,49 @@ Action::ValueDescBLineLink::prepare()
 
 			continue;
 		}
-		else if (value_desc.parent_is_layer_param())
+		else if (value_desc.parent_is_layer())
 		{
 			// VECTOR layer parameter
-			if (value_desc.get_value_type() == ValueBase::TYPE_VECTOR)
-				calculated_value_node = ValueNode_BLineCalcVertex::create(ValueBase::TYPE_VECTOR);
+			if (value_desc.get_value_type() == type_vector)
+				calculated_value_node = ValueNode_BLineCalcVertex::create(type_vector);
 			// REAL layer parameter
-			else if (value_desc.get_value_type() == ValueBase::TYPE_REAL)
-				calculated_value_node = ValueNode_BLineCalcWidth::create(ValueBase::TYPE_REAL);
+			else if (value_desc.get_value_type() == type_real)
+				calculated_value_node = ValueNode_BLineCalcWidth::create(type_real);
 			// ANGLE layer parameter
-			else if (value_desc.get_value_type() == ValueBase::TYPE_ANGLE)
-				calculated_value_node = ValueNode_BLineCalcTangent::create(ValueBase::TYPE_ANGLE);
+			else if (value_desc.get_value_type() == type_angle)
+				calculated_value_node = ValueNode_BLineCalcTangent::create(type_angle);
+			// TRANSFORMATION layer parameter
+			else if (value_desc.get_value_type() == type_transformation)
+			{
+				LinkableValueNode::Handle composite_node = ValueNode_Composite::create(value_desc.get_value(time), get_canvas());
+				LinkableValueNode::Handle offset_node = ValueNode_BLineCalcVertex::create(type_vector);
+				LinkableValueNode::Handle angle_node = ValueNode_BLineCalcTangent::create(type_angle);
+				composite_node->set_link("offset", offset_node);
+				composite_node->set_link("angle", angle_node);
+
+				offset_node->set_link("bline",  bline_value_node );
+				offset_node->set_link("loop",   loop_value_node  );
+				offset_node->set_link("amount", amount_value_node);
+				offset_node->set_link("homogeneous", homogeneous_value_node);
+
+				angle_node->set_link("bline",  bline_value_node );
+				angle_node->set_link("loop",   loop_value_node  );
+				angle_node->set_link("amount", amount_value_node);
+				angle_node->set_link("homogeneous", homogeneous_value_node);
+
+				action = LayerParamConnect::create();
+				action->set_param("layer", value_desc.get_layer());
+				action->set_param("param", value_desc.get_param_name());
+				action->set_param("canvas", get_canvas());
+				action->set_param("canvas_interface", get_canvas_interface());
+				action->set_param("value_node", ValueNode::Handle(composite_node));
+
+				assert(action->is_ready());
+				if (!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
+				add_action_front(action);
+
+				continue;
+			}
 			else
 				continue;
 
@@ -277,6 +377,6 @@ Action::ValueDescBLineLink::prepare()
 
 		assert(action->is_ready());
 		if (!action->is_ready()) throw Error(Error::TYPE_NOTREADY);
-		add_action_front(action);
+		add_action(action);
 	}
 }
