@@ -116,7 +116,7 @@ Action::ValueDescConvert::is_candidate(const ParamList &x)
 		// Don't allow to export lower and upper boundaries of the WidhtPoint
 		if(value_desc.parent_is_linkable_value_node()
 			&& value_desc.get_parent_value_node()->get_name()=="composite"
-			&& value_desc.get_parent_value_node()->get_type()==ValueBase::TYPE_WIDTHPOINT
+			&& value_desc.get_parent_value_node()->get_type()==type_width_point
 			&& (value_desc.get_index()==4 || value_desc.get_index()==5))
 		{
 			synfig::info("it is not candidate!");
@@ -256,7 +256,7 @@ Action::ValueDescConvert::prepare()
 		return;
 	}
 	else
-	if(value_desc.parent_is_layer_param())
+	if(value_desc.parent_is_layer())
 	{
 		Action::Handle action(LayerParamConnect::create());
 
